#ifndef PQCLEAN_SNTRUP953_AVX2_CRYPTO_ENCODE_953X6343_H
#define PQCLEAN_SNTRUP953_AVX2_CRYPTO_ENCODE_953X6343_H

#include <stdint.h>
#define PQCLEAN_SNTRUP953_AVX2_crypto_encode_953x6343_STRBYTES 1505
#define PQCLEAN_SNTRUP953_AVX2_crypto_encode_953x6343_ITEMS 953
#define PQCLEAN_SNTRUP953_AVX2_crypto_encode_953x6343_ITEMBYTES 2

void PQCLEAN_SNTRUP953_AVX2_crypto_encode_953x6343(unsigned char *out, const void *v);
#endif
