#ifndef PQCLEAN_SNTRUP1013_AVX2_CRYPTO_ENCODE_1013XFREEZE3_H
#define PQCLEAN_SNTRUP1013_AVX2_CRYPTO_ENCODE_1013XFREEZE3_H

#include <stdint.h>
#define PQCLEAN_SNTRUP1013_AVX2_crypto_encode_1013xfreeze3_STRBYTES 1013
#define PQCLEAN_SNTRUP1013_AVX2_crypto_encode_1013xfreeze3_ITEMS 1013
#define PQCLEAN_SNTRUP1013_AVX2_crypto_encode_1013xfreeze3_ITEMBYTES 2

void PQCLEAN_SNTRUP1013_AVX2_crypto_encode_1013xfreeze3(unsigned char *s, const void *v);
#endif
