#ifndef PQCLEAN_NTRULPR761_CLEAN_CRYPTO_VERIFY_1167_H
#define PQCLEAN_NTRULPR761_CLEAN_CRYPTO_VERIFY_1167_H

#include <stdint.h>
#define PQCLEAN_NTRULPR761_CLEAN_crypto_verify_1167_BYTES 1167

int PQCLEAN_NTRULPR761_CLEAN_crypto_verify_1167(const unsigned char *x, const unsigned char *y);
#endif
