#ifndef PQCLEAN_SNTRUP761_AVX2_CRYPTO_CORE_INV3SNTRUP761_H
#define PQCLEAN_SNTRUP761_AVX2_CRYPTO_CORE_INV3SNTRUP761_H

#include <stdint.h>
#define PQCLEAN_SNTRUP761_AVX2_crypto_core_inv3sntrup761_OUTPUTBYTES 762
#define PQCLEAN_SNTRUP761_AVX2_crypto_core_inv3sntrup761_INPUTBYTES 761
#define PQCLEAN_SNTRUP761_AVX2_crypto_core_inv3sntrup761_KEYBYTES 0
#define PQCLEAN_SNTRUP761_AVX2_crypto_core_inv3sntrup761_CONSTBYTES 0

int PQCLEAN_SNTRUP761_AVX2_crypto_core_inv3sntrup761(unsigned char *outbytes, const unsigned char *inbytes);
#endif
