#ifndef PQCLEAN_SNTRUP857_CLEAN_CRYPTO_DECODE_857X5167_H
#define PQCLEAN_SNTRUP857_CLEAN_CRYPTO_DECODE_857X5167_H

#include <stdint.h>
#define PQCLEAN_SNTRUP857_CLEAN_crypto_decode_857x5167_STRBYTES 1322
#define PQCLEAN_SNTRUP857_CLEAN_crypto_decode_857x5167_ITEMS 857
#define PQCLEAN_SNTRUP857_CLEAN_crypto_decode_857x5167_ITEMBYTES 2

void PQCLEAN_SNTRUP857_CLEAN_crypto_decode_857x5167(void *v, const unsigned char *s);
#endif
