#ifndef PQCLEAN_SNTRUP653_AVX2_CRYPTO_CORE_SCALE3SNTRUP653_H
#define PQCLEAN_SNTRUP653_AVX2_CRYPTO_CORE_SCALE3SNTRUP653_H

#include <stdint.h>
#define PQCLEAN_SNTRUP653_AVX2_crypto_core_scale3sntrup653_OUTPUTBYTES 1306
#define PQCLEAN_SNTRUP653_AVX2_crypto_core_scale3sntrup653_INPUTBYTES 1306
#define PQCLEAN_SNTRUP653_AVX2_crypto_core_scale3sntrup653_KEYBYTES 0
#define PQCLEAN_SNTRUP653_AVX2_crypto_core_scale3sntrup653_CONSTBYTES 0

int PQCLEAN_SNTRUP653_AVX2_crypto_core_scale3sntrup653(unsigned char *outbytes, const unsigned char *inbytes);
#endif
