#ifndef PQCLEAN_NTRULPR653_AVX2_CRYPTO_DECODE_653X3_H
#define PQCLEAN_NTRULPR653_AVX2_CRYPTO_DECODE_653X3_H

#include <stdint.h>
#define PQCLEAN_NTRULPR653_AVX2_crypto_decode_653x3_STRBYTES 164
#define PQCLEAN_NTRULPR653_AVX2_crypto_decode_653x3_ITEMS 653
#define PQCLEAN_NTRULPR653_AVX2_crypto_decode_653x3_ITEMBYTES 1

void PQCLEAN_NTRULPR653_AVX2_crypto_decode_653x3(void *v, const unsigned char *s);
#endif
