#ifndef PQCLEAN_NTRULPR1277_AVX2_CRYPTO_ENCODE_1277X2627ROUND_H
#define PQCLEAN_NTRULPR1277_AVX2_CRYPTO_ENCODE_1277X2627ROUND_H

#include <stdint.h>
#define PQCLEAN_NTRULPR1277_AVX2_crypto_encode_1277x2627round_STRBYTES 1815
#define PQCLEAN_NTRULPR1277_AVX2_crypto_encode_1277x2627round_ITEMS 1277
#define PQCLEAN_NTRULPR1277_AVX2_crypto_encode_1277x2627round_ITEMBYTES 2

void PQCLEAN_NTRULPR1277_AVX2_crypto_encode_1277x2627round(unsigned char *out, const void *v);
#endif
