#ifndef PQCLEAN_NTRULPR1277_AVX2_CRYPTO_VERIFY_1975_H
#define PQCLEAN_NTRULPR1277_AVX2_CRYPTO_VERIFY_1975_H

#include <stdint.h>
#define PQCLEAN_NTRULPR1277_AVX2_crypto_verify_1975_BYTES 1975

int PQCLEAN_NTRULPR1277_AVX2_crypto_verify_1975(const unsigned char *x, const unsigned char *y);
#endif
