#ifndef PQCLEAN_SNTRUP653_AVX2_CRYPTO_CORE_WFORCESNTRUP653_H
#define PQCLEAN_SNTRUP653_AVX2_CRYPTO_CORE_WFORCESNTRUP653_H

#include <stdint.h>
#define PQCLEAN_SNTRUP653_AVX2_crypto_core_wforcesntrup653_OUTPUTBYTES 653
#define PQCLEAN_SNTRUP653_AVX2_crypto_core_wforcesntrup653_INPUTBYTES 653
#define PQCLEAN_SNTRUP653_AVX2_crypto_core_wforcesntrup653_KEYBYTES 0
#define PQCLEAN_SNTRUP653_AVX2_crypto_core_wforcesntrup653_CONSTBYTES 0

int PQCLEAN_SNTRUP653_AVX2_crypto_core_wforcesntrup653(unsigned char *out, const unsigned char *in);
#endif
