#ifndef PQCLEAN_SNTRUP653_CLEAN_CRYPTO_CORE_INVSNTRUP653_H
#define PQCLEAN_SNTRUP653_CLEAN_CRYPTO_CORE_INVSNTRUP653_H

#include <stdint.h>
#define PQCLEAN_SNTRUP653_CLEAN_crypto_core_invsntrup653_OUTPUTBYTES 1307
#define PQCLEAN_SNTRUP653_CLEAN_crypto_core_invsntrup653_INPUTBYTES 653
#define PQCLEAN_SNTRUP653_CLEAN_crypto_core_invsntrup653_KEYBYTES 0
#define PQCLEAN_SNTRUP653_CLEAN_crypto_core_invsntrup653_CONSTBYTES 0

int PQCLEAN_SNTRUP653_CLEAN_crypto_core_invsntrup653(unsigned char *outbytes, const unsigned char *inbytes);
#endif
