#ifndef PQCLEAN_SNTRUP857_CLEAN_CRYPTO_CORE_MULT3SNTRUP857_H
#define PQCLEAN_SNTRUP857_CLEAN_CRYPTO_CORE_MULT3SNTRUP857_H

#include <stdint.h>
#define PQCLEAN_SNTRUP857_CLEAN_crypto_core_mult3sntrup857_OUTPUTBYTES 857
#define PQCLEAN_SNTRUP857_CLEAN_crypto_core_mult3sntrup857_INPUTBYTES 857
#define PQCLEAN_SNTRUP857_CLEAN_crypto_core_mult3sntrup857_KEYBYTES 857
#define PQCLEAN_SNTRUP857_CLEAN_crypto_core_mult3sntrup857_CONSTBYTES 0

int PQCLEAN_SNTRUP857_CLEAN_crypto_core_mult3sntrup857(unsigned char *outbytes, const unsigned char *inbytes, const unsigned char *kbytes);
#endif
