.data
.p2align 5
mask_0_1:
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 10
.byte 6
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255

mask_1_1:
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x202
.word 0x202
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x404
.word 0x404
.word 0x0
.word 0x0

mask_2_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 9
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255

mask_3_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x808
.word 0x808
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1010
.word 0x1010
.word 0x0
.word 0x0

mask_4_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 10
.byte 6
.byte 2

mask_5_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x202
.word 0x202
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x404
.word 0x404

mask_6_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 9
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 0

mask_7_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x808
.word 0x808
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1010
.word 0x1010

mask_8_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255

mask_9_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4040
.word 0x4040
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x8080
.word 0x80
.word 0x0
.word 0x0

mask_10_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0

mask_11_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 10
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_12_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x101
.word 0x101
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x202
.word 0x2
.word 0x0
.word 0x0

mask_13_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3
.byte 2

mask_14_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4040
.word 0x4040
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x8080
.word 0x80

mask_15_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200

mask_16_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 10
.byte 6
.byte 255

mask_17_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x101
.word 0x101
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x202
.word 0x2

mask_18_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 10
.byte 6
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 13
.byte 9
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255

mask_19_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x808
.word 0x808
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1010
.word 0x1010
.word 0x0
.word 0x0

mask_20_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_21_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_22_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2020
.word 0x2020
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4040
.word 0x40
.word 0x0
.word 0x0

mask_23_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 10
.byte 6
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 13
.byte 9
.byte 5
.byte 1

mask_24_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x808
.word 0x808
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1010
.word 0x1010

mask_25_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0

mask_26_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 7
.byte 3
.byte 255

mask_27_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2020
.word 0x2020
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4040
.word 0x40

mask_28_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 255
.byte 255
.byte 14
.byte 12
.byte 8
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255

mask_29_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x100
.word 0x101
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x202
.word 0x202
.word 0x0
.word 0x0

mask_30_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_31_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 10
.byte 6
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 9
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255

mask_32_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x404
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x808
.word 0x808
.word 0x0
.word 0x0

mask_33_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3

mask_34_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x101
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x202
.word 0x202

mask_35_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_36_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 10
.byte 6
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 9
.byte 5
.byte 1

mask_37_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x404
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x808
.word 0x808

mask_38_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 13
.byte 9
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255

mask_39_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2020
.word 0x2020
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4040
.word 0x4040
.word 0x0
.word 0x0

mask_40_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_41_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255

mask_42_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8080
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x101
.word 0x101
.word 0x0
.word 0x0

mask_43_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 13
.byte 9
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 0

mask_44_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2020
.word 0x2020
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4040
.word 0x4040

mask_45_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_46_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3

mask_47_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8080
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x101
.word 0x101

mask_48_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 10
.byte 6
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255

mask_49_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x404
.word 0x404
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x808
.word 0x808
.word 0x0
.word 0x0

mask_50_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 9
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255

mask_51_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1010
.word 0x1010
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2020
.word 0x2020
.word 0x0
.word 0x0

mask_52_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 10
.byte 6
.byte 2

mask_53_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x404
.word 0x404
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x808
.word 0x808

mask_54_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 9
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 255

mask_55_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1010
.word 0x1010
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2020
.word 0x20

mask_56_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255

mask_57_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8080
.word 0x8080
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x101
.word 0x1
.word 0x0

mask_58_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0

mask_59_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 10
.byte 6
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255

mask_60_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x202
.word 0x202
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x404
.word 0x0
.word 0x0

mask_61_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 255
.byte 255
.byte 14
.byte 12
.byte 8
.byte 4

mask_62_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8080
.word 0x8080
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x100
.word 0x101

mask_63_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0

mask_64_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 10
.byte 6
.byte 2

mask_65_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x202
.word 0x202
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x404

mask_66_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 10
.byte 6
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 13
.byte 9
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255

mask_67_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1010
.word 0x1010
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2020
.word 0x2020
.word 0x0
.word 0x0

mask_68_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_69_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_70_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4040
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8080
.word 0x80
.word 0x0
.word 0x0

mask_71_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 10
.byte 6
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 13
.byte 9
.byte 5
.byte 1

mask_72_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1010
.word 0x1010
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2020
.word 0x2020

mask_73_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0

mask_74_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 7
.byte 3
.byte 255

mask_75_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4040
.word 0x4040
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8080
.word 0x80

mask_76_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 10
.byte 6
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_77_1:
.word 0x0
.word 0x0
.word 0x202
.word 0x202
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x404
.word 0x404
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_78_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 9
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_79_1:
.word 0x0
.word 0x0
.word 0x808
.word 0x808
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1010
.word 0x1010
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_80_1:
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 10
.byte 6
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_81_1:
.word 0x202
.word 0x202
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x404
.word 0x404
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_82_1:
.byte 13
.byte 9
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_83_1:
.word 0x808
.word 0x808
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1010
.word 0x1010
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_84_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 7
.byte 3
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_85_1:
.word 0x0
.word 0x0
.word 0x4040
.word 0x4040
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8080
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_86_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_87_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 10
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_88_1:
.word 0x0
.word 0x0
.word 0x101
.word 0x101
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x202
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_89_1:
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_90_1:
.word 0x4040
.word 0x4040
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x8080
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_91_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_92_1:
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 10
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_93_1:
.word 0x101
.word 0x101
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x202
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_94_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 10
.byte 6
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 9
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_95_1:
.word 0x0
.word 0x0
.word 0x808
.word 0x808
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1010
.word 0x1010
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_96_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_97_1:
.word 0x0
.word 0x0
.word 0x2020
.word 0x2020
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4040
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_98_1:
.byte 14
.byte 10
.byte 6
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 255
.byte 255
.byte 255
.byte 15
.byte 13
.byte 9
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_99_1:
.word 0x808
.word 0x808
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1010
.word 0x1010
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_100_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_101_1:
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_102_1:
.word 0x2020
.word 0x2020
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4040
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_103_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 12
.byte 8
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_104_1:
.word 0x0
.word 0x0
.word 0x100
.word 0x101
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x202
.word 0x202
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_105_1:
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_106_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 10
.byte 6
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 9
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_107_1:
.word 0x0
.word 0x0
.word 0x400
.word 0x404
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x808
.word 0x808
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_108_1:
.byte 14
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_109_1:
.word 0x100
.word 0x101
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x202
.word 0x202
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_110_1:
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_111_1:
.byte 255
.byte 10
.byte 6
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 9
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_112_1:
.word 0x400
.word 0x404
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x808
.word 0x808
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_113_1:
.byte 255
.byte 255
.byte 255
.byte 15
.byte 13
.byte 9
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15

mask_114_1:
.word 0x0
.word 0x0
.word 0x2020
.word 0x2020
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4040
.word 0x4040
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000

mask_115_1:
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_116_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_117_1:
.word 0x0
.word 0x0
.word 0x8080
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x101
.word 0x101
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_118_1:
.byte 13
.byte 9
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_119_1:
.word 0x2020
.word 0x2020
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4040
.word 0x4040
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_120_1:
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_121_1:
.word 0x8080
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x101
.word 0x101
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_122_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 10
.byte 6
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_123_1:
.word 0x0
.word 0x0
.word 0x404
.word 0x404
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x808
.word 0x808
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_124_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 9
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_125_1:
.word 0x0
.word 0x0
.word 0x1010
.word 0x1010
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2020
.word 0x2020
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_126_1:
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 10
.byte 6
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_127_1:
.word 0x404
.word 0x404
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x808
.word 0x808
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_128_1:
.byte 13
.byte 9
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_129_1:
.word 0x1010
.word 0x1010
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2020
.word 0x2020
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_130_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_131_1:
.word 0x0
.word 0x0
.word 0x8080
.word 0x8080
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x101
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_132_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_133_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 10
.byte 6
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_134_1:
.word 0x0
.word 0x0
.word 0x202
.word 0x202
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x404
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_135_1:
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 255
.byte 255
.byte 14
.byte 12
.byte 8
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_136_1:
.word 0x8080
.word 0x8080
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x100
.word 0x101
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_137_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_138_1:
.byte 15
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 10
.byte 6
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_139_1:
.word 0x202
.word 0x202
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x404
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_140_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 10
.byte 6
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 9
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_141_1:
.word 0x0
.word 0x0
.word 0x1010
.word 0x1010
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2020
.word 0x2020
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_142_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_143_1:
.word 0x0
.word 0x0
.word 0x4040
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8080
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_144_1:
.byte 14
.byte 10
.byte 6
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 255
.byte 255
.byte 255
.byte 15
.byte 13
.byte 9
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_145_1:
.word 0x1010
.word 0x1010
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2020
.word 0x2020
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_146_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_147_1:
.byte 12
.byte 8
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 7
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_148_1:
.word 0x4040
.word 0x4040
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8080
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0

.text
.global PQCLEAN_NTRUHPS2048509_AVX2_square_252_509
.global _PQCLEAN_NTRUHPS2048509_AVX2_square_252_509
PQCLEAN_NTRUHPS2048509_AVX2_square_252_509:
_PQCLEAN_NTRUHPS2048509_AVX2_square_252_509:
vmovdqa 0(%rsi), %ymm0
vpshufb mask_0_1(%rip), %ymm0, %ymm4
vpand mask_1_1(%rip), %ymm4, %ymm1
vpshufb mask_2_1(%rip), %ymm0, %ymm4
vpand mask_3_1(%rip), %ymm4, %ymm2
vpermq $78, %ymm0, %ymm7
vpshufb mask_4_1(%rip), %ymm7, %ymm4
vpand mask_5_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpshufb mask_6_1(%rip), %ymm7, %ymm4
vpand mask_7_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpsllq $1, %ymm0, %ymm5
vpshufb mask_8_1(%rip), %ymm5, %ymm4
vpand mask_9_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpand mask_10_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpshufb mask_11_1(%rip), %ymm5, %ymm4
vpand mask_12_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpermq $78, %ymm5, %ymm7
vpshufb mask_13_1(%rip), %ymm7, %ymm4
vpand mask_14_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpand mask_15_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpshufb mask_16_1(%rip), %ymm7, %ymm4
vpand mask_17_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpsllq $2, %ymm0, %ymm5
vpshufb mask_18_1(%rip), %ymm5, %ymm4
vpand mask_19_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpand mask_20_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpshufb mask_21_1(%rip), %ymm5, %ymm4
vpand mask_22_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpermq $78, %ymm5, %ymm7
vpshufb mask_23_1(%rip), %ymm7, %ymm4
vpand mask_24_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpand mask_25_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpshufb mask_26_1(%rip), %ymm7, %ymm4
vpand mask_27_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpsrlq $61, %ymm0, %ymm4
vpsllq $3, %ymm0, %ymm3
vpermq $147, %ymm4, %ymm5
vpxor %ymm3, %ymm5, %ymm5
vpshufb mask_28_1(%rip), %ymm5, %ymm4
vpand mask_29_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpand mask_30_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpshufb mask_31_1(%rip), %ymm5, %ymm4
vpand mask_32_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpermq $78, %ymm5, %ymm7
vpshufb mask_33_1(%rip), %ymm7, %ymm4
vpand mask_34_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpand mask_35_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpshufb mask_36_1(%rip), %ymm7, %ymm4
vpand mask_37_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpsllq $1, %ymm5, %ymm6
vpshufb mask_38_1(%rip), %ymm6, %ymm4
vpand mask_39_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpand mask_40_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpshufb mask_41_1(%rip), %ymm6, %ymm4
vpand mask_42_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpermq $78, %ymm6, %ymm7
vpshufb mask_43_1(%rip), %ymm7, %ymm4
vpand mask_44_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpand mask_45_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpshufb mask_46_1(%rip), %ymm7, %ymm4
vpand mask_47_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpsllq $2, %ymm5, %ymm6
vpshufb mask_48_1(%rip), %ymm6, %ymm4
vpand mask_49_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpshufb mask_50_1(%rip), %ymm6, %ymm4
vpand mask_51_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpermq $78, %ymm6, %ymm7
vpshufb mask_52_1(%rip), %ymm7, %ymm4
vpand mask_53_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpshufb mask_54_1(%rip), %ymm7, %ymm4
vpand mask_55_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpsrlq $61, %ymm5, %ymm4
vpsllq $3, %ymm5, %ymm3
vpermq $147, %ymm4, %ymm6
vpxor %ymm3, %ymm6, %ymm6
vpshufb mask_56_1(%rip), %ymm6, %ymm4
vpand mask_57_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpand mask_58_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpshufb mask_59_1(%rip), %ymm6, %ymm4
vpand mask_60_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpermq $78, %ymm6, %ymm7
vpshufb mask_61_1(%rip), %ymm7, %ymm4
vpand mask_62_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpand mask_63_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpshufb mask_64_1(%rip), %ymm7, %ymm4
vpand mask_65_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpsllq $1, %ymm6, %ymm5
vpshufb mask_66_1(%rip), %ymm5, %ymm4
vpand mask_67_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpand mask_68_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpshufb mask_69_1(%rip), %ymm5, %ymm4
vpand mask_70_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpermq $78, %ymm5, %ymm7
vpshufb mask_71_1(%rip), %ymm7, %ymm4
vpand mask_72_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpand mask_73_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpshufb mask_74_1(%rip), %ymm7, %ymm4
vpand mask_75_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vmovdqa 32(%rsi), %ymm0
vpshufb mask_76_1(%rip), %ymm0, %ymm4
vpand mask_77_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpshufb mask_78_1(%rip), %ymm0, %ymm4
vpand mask_79_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpermq $78, %ymm0, %ymm7
vpshufb mask_80_1(%rip), %ymm7, %ymm4
vpand mask_81_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpshufb mask_82_1(%rip), %ymm7, %ymm4
vpand mask_83_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpsllq $1, %ymm0, %ymm5
vpshufb mask_84_1(%rip), %ymm5, %ymm4
vpand mask_85_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpand mask_86_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpshufb mask_87_1(%rip), %ymm5, %ymm4
vpand mask_88_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpermq $78, %ymm5, %ymm7
vpshufb mask_89_1(%rip), %ymm7, %ymm4
vpand mask_90_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpand mask_91_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpshufb mask_92_1(%rip), %ymm7, %ymm4
vpand mask_93_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpsllq $2, %ymm0, %ymm5
vpshufb mask_94_1(%rip), %ymm5, %ymm4
vpand mask_95_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpshufb mask_96_1(%rip), %ymm5, %ymm4
vpand mask_97_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpermq $78, %ymm5, %ymm7
vpshufb mask_98_1(%rip), %ymm7, %ymm4
vpand mask_99_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpand mask_100_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpshufb mask_101_1(%rip), %ymm7, %ymm4
vpand mask_102_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpsrlq $61, %ymm0, %ymm4
vpsllq $3, %ymm0, %ymm3
vpermq $147, %ymm4, %ymm5
vpxor %ymm3, %ymm5, %ymm5
vpshufb mask_103_1(%rip), %ymm5, %ymm4
vpand mask_104_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpand mask_105_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpshufb mask_106_1(%rip), %ymm5, %ymm4
vpand mask_107_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpermq $78, %ymm5, %ymm7
vpshufb mask_108_1(%rip), %ymm7, %ymm4
vpand mask_109_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpand mask_110_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpshufb mask_111_1(%rip), %ymm7, %ymm4
vpand mask_112_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpsllq $1, %ymm5, %ymm6
vpshufb mask_113_1(%rip), %ymm6, %ymm4
vpand mask_114_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpand mask_115_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpshufb mask_116_1(%rip), %ymm6, %ymm4
vpand mask_117_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpermq $78, %ymm6, %ymm7
vpshufb mask_118_1(%rip), %ymm7, %ymm4
vpand mask_119_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpshufb mask_120_1(%rip), %ymm7, %ymm4
vpand mask_121_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpsllq $2, %ymm5, %ymm6
vpshufb mask_122_1(%rip), %ymm6, %ymm4
vpand mask_123_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpshufb mask_124_1(%rip), %ymm6, %ymm4
vpand mask_125_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpermq $78, %ymm6, %ymm7
vpshufb mask_126_1(%rip), %ymm7, %ymm4
vpand mask_127_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpshufb mask_128_1(%rip), %ymm7, %ymm4
vpand mask_129_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpsrlq $61, %ymm5, %ymm4
vpsllq $3, %ymm5, %ymm3
vpermq $147, %ymm4, %ymm6
vpxor %ymm3, %ymm6, %ymm6
vpshufb mask_130_1(%rip), %ymm6, %ymm4
vpand mask_131_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpand mask_132_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpshufb mask_133_1(%rip), %ymm6, %ymm4
vpand mask_134_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpermq $78, %ymm6, %ymm7
vpshufb mask_135_1(%rip), %ymm7, %ymm4
vpand mask_136_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpand mask_137_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpshufb mask_138_1(%rip), %ymm7, %ymm4
vpand mask_139_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpsllq $1, %ymm6, %ymm5
vpshufb mask_140_1(%rip), %ymm5, %ymm4
vpand mask_141_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpshufb mask_142_1(%rip), %ymm5, %ymm4
vpand mask_143_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpermq $78, %ymm5, %ymm7
vpshufb mask_144_1(%rip), %ymm7, %ymm4
vpand mask_145_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm1, %ymm1
vpand mask_146_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vpshufb mask_147_1(%rip), %ymm7, %ymm4
vpand mask_148_1(%rip), %ymm4, %ymm3
vpxor %ymm3, %ymm2, %ymm2
vmovdqa %ymm1, 0(%rdi)
vmovdqa %ymm2, 32(%rdi)
ret
