#ifndef PQCLEAN_MCELIECE8192128_CLEAN_BM_H
#define PQCLEAN_MCELIECE8192128_CLEAN_BM_H
/*
  This file is for the Berlekamp-Massey algorithm
  see http://crypto.stanford.edu/~mironov/cs359/massey.pdf
*/

#include "gf.h"

void PQCLEAN_MCELIECE8192128_CLEAN_bm(gf * /*out*/, gf * /*s*/);

#endif

