#ifndef PQCLEAN_SNTRUP653_AVX2_CRYPTO_CORE_WEIGHTSNTRUP653_H
#define PQCLEAN_SNTRUP653_AVX2_CRYPTO_CORE_WEIGHTSNTRUP653_H

#include <stdint.h>
#define PQCLEAN_SNTRUP653_AVX2_crypto_core_weightsntrup653_OUTPUTBYTES 2
#define PQCLEAN_SNTRUP653_AVX2_crypto_core_weightsntrup653_INPUTBYTES 653
#define PQCLEAN_SNTRUP653_AVX2_crypto_core_weightsntrup653_KEYBYTES 0
#define PQCLEAN_SNTRUP653_AVX2_crypto_core_weightsntrup653_CONSTBYTES 0

int PQCLEAN_SNTRUP653_AVX2_crypto_core_weightsntrup653(unsigned char *outbytes, const unsigned char *inbytes);
#endif
