#ifndef PQCLEAN_SNTRUP653_AVX2_CRYPTO_VERIFY_897_H
#define PQCLEAN_SNTRUP653_AVX2_CRYPTO_VERIFY_897_H

#include <stdint.h>
#define PQCLEAN_SNTRUP653_AVX2_crypto_verify_897_BYTES 897

int PQCLEAN_SNTRUP653_AVX2_crypto_verify_897(const unsigned char *x, const unsigned char *y);
#endif
