#ifndef PQCLEAN_SNTRUP1277_AVX2_CRYPTO_ENCODE_1277XFREEZE3_H
#define PQCLEAN_SNTRUP1277_AVX2_CRYPTO_ENCODE_1277XFREEZE3_H

#include <stdint.h>
#define PQCLEAN_SNTRUP1277_AVX2_crypto_encode_1277xfreeze3_STRBYTES 1277
#define PQCLEAN_SNTRUP1277_AVX2_crypto_encode_1277xfreeze3_ITEMS 1277
#define PQCLEAN_SNTRUP1277_AVX2_crypto_encode_1277xfreeze3_ITEMBYTES 2

void PQCLEAN_SNTRUP1277_AVX2_crypto_encode_1277xfreeze3(unsigned char *s, const void *v);
#endif
