#ifndef PQCLEAN_SNTRUP1013_AVX2_CRYPTO_CORE_WFORCESNTRUP1013_H
#define PQCLEAN_SNTRUP1013_AVX2_CRYPTO_CORE_WFORCESNTRUP1013_H

#include <stdint.h>
#define PQCLEAN_SNTRUP1013_AVX2_crypto_core_wforcesntrup1013_OUTPUTBYTES 1013
#define PQCLEAN_SNTRUP1013_AVX2_crypto_core_wforcesntrup1013_INPUTBYTES 1013
#define PQCLEAN_SNTRUP1013_AVX2_crypto_core_wforcesntrup1013_KEYBYTES 0
#define PQCLEAN_SNTRUP1013_AVX2_crypto_core_wforcesntrup1013_CONSTBYTES 0

int PQCLEAN_SNTRUP1013_AVX2_crypto_core_wforcesntrup1013(unsigned char *out, const unsigned char *in);
#endif
