#ifndef PQCLEAN_SNTRUP1277_AVX2_CRYPTO_ENCODE_1277X7879_H
#define PQCLEAN_SNTRUP1277_AVX2_CRYPTO_ENCODE_1277X7879_H

#include <stdint.h>
#define PQCLEAN_SNTRUP1277_AVX2_crypto_encode_1277x7879_STRBYTES 2067
#define PQCLEAN_SNTRUP1277_AVX2_crypto_encode_1277x7879_ITEMS 1277
#define PQCLEAN_SNTRUP1277_AVX2_crypto_encode_1277x7879_ITEMBYTES 2

void PQCLEAN_SNTRUP1277_AVX2_crypto_encode_1277x7879(unsigned char *out, const void *v);
#endif
