#ifndef PQCLEAN_KYBER1024_AVX2_CONSTS_H
#define PQCLEAN_KYBER1024_AVX2_CONSTS_H
#include "align.h"
#include "cdecl.h"


typedef ALIGNED_INT16(640) qdata_t;
extern const qdata_t PQCLEAN_KYBER1024_AVX2_qdata;

#endif
