#ifndef PQCLEAN_SNTRUP953_CLEAN_CRYPTO_SORT_UINT32_H
#define PQCLEAN_SNTRUP953_CLEAN_CRYPTO_SORT_UINT32_H

#include <stdint.h>
#define PQCLEAN_SNTRUP953_CLEAN_crypto_sort_uint32_BYTES 4

void PQCLEAN_SNTRUP953_CLEAN_crypto_sort_uint32(void *array, long long n);
#endif
