#ifndef PQCLEAN_SNTRUP953_CLEAN_CRYPTO_SORT_INT32_H
#define PQCLEAN_SNTRUP953_CLEAN_CRYPTO_SORT_INT32_H

#include <stdint.h>
#define PQCLEAN_SNTRUP953_CLEAN_crypto_sort_int32_BYTES 4

void PQCLEAN_SNTRUP953_CLEAN_crypto_sort_int32(int32_t *x, long long n);
#endif
