#ifndef PQCLEAN_NTRULPR1013_AVX2_CRYPTO_ENCODE_1013X3_H
#define PQCLEAN_NTRULPR1013_AVX2_CRYPTO_ENCODE_1013X3_H

#include <stdint.h>
#define PQCLEAN_NTRULPR1013_AVX2_crypto_encode_1013x3_STRBYTES 254
#define PQCLEAN_NTRULPR1013_AVX2_crypto_encode_1013x3_ITEMS 1013
#define PQCLEAN_NTRULPR1013_AVX2_crypto_encode_1013x3_ITEMBYTES 1

void PQCLEAN_NTRULPR1013_AVX2_crypto_encode_1013x3(unsigned char *s, const void *v);
#endif
