#ifndef PQCLEAN_NTRULPR653_AVX2_CRYPTO_ENCODE_653X1541ROUND_H
#define PQCLEAN_NTRULPR653_AVX2_CRYPTO_ENCODE_653X1541ROUND_H

#include <stdint.h>
#define PQCLEAN_NTRULPR653_AVX2_crypto_encode_653x1541round_STRBYTES 865
#define PQCLEAN_NTRULPR653_AVX2_crypto_encode_653x1541round_ITEMS 653
#define PQCLEAN_NTRULPR653_AVX2_crypto_encode_653x1541round_ITEMBYTES 2

void PQCLEAN_NTRULPR653_AVX2_crypto_encode_653x1541round(unsigned char *out, const void *v);
#endif
