#ifndef PQCLEAN_NTRULPR761_CLEAN_CRYPTO_CORE_MULTSNTRUP761_H
#define PQCLEAN_NTRULPR761_CLEAN_CRYPTO_CORE_MULTSNTRUP761_H

#include <stdint.h>
#define PQCLEAN_NTRULPR761_CLEAN_crypto_core_multsntrup761_OUTPUTBYTES 1522
#define PQCLEAN_NTRULPR761_CLEAN_crypto_core_multsntrup761_INPUTBYTES 1522
#define PQCLEAN_NTRULPR761_CLEAN_crypto_core_multsntrup761_KEYBYTES 761
#define PQCLEAN_NTRULPR761_CLEAN_crypto_core_multsntrup761_CONSTBYTES 0

int PQCLEAN_NTRULPR761_CLEAN_crypto_core_multsntrup761(unsigned char *outbytes, const unsigned char *inbytes, const unsigned char *kbytes);
#endif
