#ifndef PQCLEAN_SNTRUP1013_CLEAN_CRYPTO_CORE_INV3SNTRUP1013_H
#define PQCLEAN_SNTRUP1013_CLEAN_CRYPTO_CORE_INV3SNTRUP1013_H

#include <stdint.h>
#define PQCLEAN_SNTRUP1013_CLEAN_crypto_core_inv3sntrup1013_OUTPUTBYTES 1014
#define PQCLEAN_SNTRUP1013_CLEAN_crypto_core_inv3sntrup1013_INPUTBYTES 1013
#define PQCLEAN_SNTRUP1013_CLEAN_crypto_core_inv3sntrup1013_KEYBYTES 0
#define PQCLEAN_SNTRUP1013_CLEAN_crypto_core_inv3sntrup1013_CONSTBYTES 0

int PQCLEAN_SNTRUP1013_CLEAN_crypto_core_inv3sntrup1013(unsigned char *outbytes, const unsigned char *inbytes);
#endif
