#ifndef PQCLEAN_NTRULPR1013_AVX2_CRYPTO_DECODE_1013XINT32_H
#define PQCLEAN_NTRULPR1013_AVX2_CRYPTO_DECODE_1013XINT32_H

#include <stdint.h>
#define PQCLEAN_NTRULPR1013_AVX2_crypto_decode_1013xint32_STRBYTES 4052
#define PQCLEAN_NTRULPR1013_AVX2_crypto_decode_1013xint32_ITEMS 1013
#define PQCLEAN_NTRULPR1013_AVX2_crypto_decode_1013xint32_ITEMBYTES 4

void PQCLEAN_NTRULPR1013_AVX2_crypto_decode_1013xint32(void *v, const unsigned char *s);
#endif
