#ifndef PQCLEAN_NTRULPR953_CLEAN_CRYPTO_DECODE_953XINT16_H
#define PQCLEAN_NTRULPR953_CLEAN_CRYPTO_DECODE_953XINT16_H

#include <stdint.h>
#define PQCLEAN_NTRULPR953_CLEAN_crypto_decode_953xint16_STRBYTES 1906
#define PQCLEAN_NTRULPR953_CLEAN_crypto_decode_953xint16_ITEMS 953
#define PQCLEAN_NTRULPR953_CLEAN_crypto_decode_953xint16_ITEMBYTES 2

void PQCLEAN_NTRULPR953_CLEAN_crypto_decode_953xint16(void *v, const unsigned char *s);
#endif
