#ifndef PQCLEAN_SNTRUP653_CLEAN_CRYPTO_ENCODE_653XFREEZE3_H
#define PQCLEAN_SNTRUP653_CLEAN_CRYPTO_ENCODE_653XFREEZE3_H

#include <stdint.h>
#define PQCLEAN_SNTRUP653_CLEAN_crypto_encode_653xfreeze3_STRBYTES 653
#define PQCLEAN_SNTRUP653_CLEAN_crypto_encode_653xfreeze3_ITEMS 653
#define PQCLEAN_SNTRUP653_CLEAN_crypto_encode_653xfreeze3_ITEMBYTES 2

void PQCLEAN_SNTRUP653_CLEAN_crypto_encode_653xfreeze3(unsigned char *s, const void *v);
#endif
