#ifndef PQCLEAN_NTRULPR761_CLEAN_CRYPTO_ENCODE_256X2_H
#define PQCLEAN_NTRULPR761_CLEAN_CRYPTO_ENCODE_256X2_H

#include <stdint.h>
#define PQCLEAN_NTRULPR761_CLEAN_crypto_encode_256x2_STRBYTES 32
#define PQCLEAN_NTRULPR761_CLEAN_crypto_encode_256x2_ITEMS 256
#define PQCLEAN_NTRULPR761_CLEAN_crypto_encode_256x2_ITEMBYTES 1

void PQCLEAN_NTRULPR761_CLEAN_crypto_encode_256x2(unsigned char *s, const void *v);
#endif
