#ifndef PQCLEAN_SNTRUP1013_CLEAN_CRYPTO_ENCODE_1013X7177_H
#define PQCLEAN_SNTRUP1013_CLEAN_CRYPTO_ENCODE_1013X7177_H

#include <stdint.h>
#define PQCLEAN_SNTRUP1013_CLEAN_crypto_encode_1013x7177_STRBYTES 1623
#define PQCLEAN_SNTRUP1013_CLEAN_crypto_encode_1013x7177_ITEMS 1013
#define PQCLEAN_SNTRUP1013_CLEAN_crypto_encode_1013x7177_ITEMBYTES 2

void PQCLEAN_SNTRUP1013_CLEAN_crypto_encode_1013x7177(unsigned char *out, const void *v);
#endif
