#ifndef PQCLEAN_MCELIECE8192128F_SSE_DECRYPT_H
#define PQCLEAN_MCELIECE8192128F_SSE_DECRYPT_H
/*
  This file is for Nieddereiter decryption
*/

int PQCLEAN_MCELIECE8192128F_SSE_decrypt(unsigned char * /*e*/, const unsigned char * /*sk*/, const unsigned char * /*c*/);

#endif

