#ifndef PQCLEAN_SNTRUP653_AVX2_CRYPTO_CORE_MULT3SNTRUP653_H
#define PQCLEAN_SNTRUP653_AVX2_CRYPTO_CORE_MULT3SNTRUP653_H

#include <stdint.h>
#define PQCLEAN_SNTRUP653_AVX2_crypto_core_mult3sntrup653_OUTPUTBYTES 653
#define PQCLEAN_SNTRUP653_AVX2_crypto_core_mult3sntrup653_INPUTBYTES 653
#define PQCLEAN_SNTRUP653_AVX2_crypto_core_mult3sntrup653_KEYBYTES 653
#define PQCLEAN_SNTRUP653_AVX2_crypto_core_mult3sntrup653_CONSTBYTES 0

int PQCLEAN_SNTRUP653_AVX2_crypto_core_mult3sntrup653(unsigned char *outbytes, const unsigned char *inbytes, const unsigned char *kbytes);
#endif
