#ifndef PQCLEAN_SNTRUP653_AVX2_CRYPTO_ENCODE_653X3_H
#define PQCLEAN_SNTRUP653_AVX2_CRYPTO_ENCODE_653X3_H

#include <stdint.h>
#define PQCLEAN_SNTRUP653_AVX2_crypto_encode_653x3_STRBYTES 164
#define PQCLEAN_SNTRUP653_AVX2_crypto_encode_653x3_ITEMS 653
#define PQCLEAN_SNTRUP653_AVX2_crypto_encode_653x3_ITEMBYTES 1

void PQCLEAN_SNTRUP653_AVX2_crypto_encode_653x3(unsigned char *s, const void *v);
#endif
