#ifndef PQCLEAN_SNTRUP953_AVX2_CRYPTO_ENCODE_953XINT16_H
#define PQCLEAN_SNTRUP953_AVX2_CRYPTO_ENCODE_953XINT16_H

#include <stdint.h>
#define PQCLEAN_SNTRUP953_AVX2_crypto_encode_953xint16_STRBYTES 1906
#define PQCLEAN_SNTRUP953_AVX2_crypto_encode_953xint16_ITEMS 953
#define PQCLEAN_SNTRUP953_AVX2_crypto_encode_953xint16_ITEMBYTES 2

void PQCLEAN_SNTRUP953_AVX2_crypto_encode_953xint16(unsigned char *s, const void *v);
#endif
