#if defined(__APPLE__)
    #define ASM_HIDDEN .private_extern
#else
    #define ASM_HIDDEN .hidden
#endif

.data

.globl PQCLEAN_MCELIECE348864F_SSE_MASK0_0
.globl PQCLEAN_MCELIECE348864F_SSE_MASK0_1
.globl PQCLEAN_MCELIECE348864F_SSE_MASK1_0
.globl PQCLEAN_MCELIECE348864F_SSE_MASK1_1
.globl PQCLEAN_MCELIECE348864F_SSE_MASK2_0
.globl PQCLEAN_MCELIECE348864F_SSE_MASK2_1
.globl PQCLEAN_MCELIECE348864F_SSE_MASK3_0
.globl PQCLEAN_MCELIECE348864F_SSE_MASK3_1
.globl PQCLEAN_MCELIECE348864F_SSE_MASK4_0
.globl PQCLEAN_MCELIECE348864F_SSE_MASK4_1
.globl PQCLEAN_MCELIECE348864F_SSE_MASK5_0
.globl PQCLEAN_MCELIECE348864F_SSE_MASK5_1

ASM_HIDDEN PQCLEAN_MCELIECE348864F_SSE_MASK0_0
ASM_HIDDEN PQCLEAN_MCELIECE348864F_SSE_MASK0_1
ASM_HIDDEN PQCLEAN_MCELIECE348864F_SSE_MASK1_0
ASM_HIDDEN PQCLEAN_MCELIECE348864F_SSE_MASK1_1
ASM_HIDDEN PQCLEAN_MCELIECE348864F_SSE_MASK2_0
ASM_HIDDEN PQCLEAN_MCELIECE348864F_SSE_MASK2_1
ASM_HIDDEN PQCLEAN_MCELIECE348864F_SSE_MASK3_0
ASM_HIDDEN PQCLEAN_MCELIECE348864F_SSE_MASK3_1
ASM_HIDDEN PQCLEAN_MCELIECE348864F_SSE_MASK4_0
ASM_HIDDEN PQCLEAN_MCELIECE348864F_SSE_MASK4_1
ASM_HIDDEN PQCLEAN_MCELIECE348864F_SSE_MASK5_0
ASM_HIDDEN PQCLEAN_MCELIECE348864F_SSE_MASK5_1

.p2align 4

PQCLEAN_MCELIECE348864F_SSE_MASK0_0: .quad 0x5555555555555555, 0x5555555555555555
PQCLEAN_MCELIECE348864F_SSE_MASK0_1: .quad 0xAAAAAAAAAAAAAAAA, 0xAAAAAAAAAAAAAAAA
PQCLEAN_MCELIECE348864F_SSE_MASK1_0: .quad 0x3333333333333333, 0x3333333333333333
PQCLEAN_MCELIECE348864F_SSE_MASK1_1: .quad 0xCCCCCCCCCCCCCCCC, 0xCCCCCCCCCCCCCCCC
PQCLEAN_MCELIECE348864F_SSE_MASK2_0: .quad 0x0F0F0F0F0F0F0F0F, 0x0F0F0F0F0F0F0F0F
PQCLEAN_MCELIECE348864F_SSE_MASK2_1: .quad 0xF0F0F0F0F0F0F0F0, 0xF0F0F0F0F0F0F0F0
PQCLEAN_MCELIECE348864F_SSE_MASK3_0: .quad 0x00FF00FF00FF00FF, 0x00FF00FF00FF00FF
PQCLEAN_MCELIECE348864F_SSE_MASK3_1: .quad 0xFF00FF00FF00FF00, 0xFF00FF00FF00FF00
PQCLEAN_MCELIECE348864F_SSE_MASK4_0: .quad 0x0000FFFF0000FFFF, 0x0000FFFF0000FFFF
PQCLEAN_MCELIECE348864F_SSE_MASK4_1: .quad 0xFFFF0000FFFF0000, 0xFFFF0000FFFF0000
PQCLEAN_MCELIECE348864F_SSE_MASK5_0: .quad 0x00000000FFFFFFFF, 0x00000000FFFFFFFF
PQCLEAN_MCELIECE348864F_SSE_MASK5_1: .quad 0xFFFFFFFF00000000, 0xFFFFFFFF00000000
