#ifndef PQCLEAN_SNTRUP857_CLEAN_CRYPTO_DECODE_857X3_H
#define PQCLEAN_SNTRUP857_CLEAN_CRYPTO_DECODE_857X3_H

#include <stdint.h>
#define PQCLEAN_SNTRUP857_CLEAN_crypto_decode_857x3_STRBYTES 215
#define PQCLEAN_SNTRUP857_CLEAN_crypto_decode_857x3_ITEMS 857
#define PQCLEAN_SNTRUP857_CLEAN_crypto_decode_857x3_ITEMBYTES 1

void PQCLEAN_SNTRUP857_CLEAN_crypto_decode_857x3(void *v, const unsigned char *s);
#endif
