#ifndef PQCLEAN_SNTRUP857_AVX2_CRYPTO_ENCODE_857XFREEZE3_H
#define PQCLEAN_SNTRUP857_AVX2_CRYPTO_ENCODE_857XFREEZE3_H

#include <stdint.h>
#define PQCLEAN_SNTRUP857_AVX2_crypto_encode_857xfreeze3_STRBYTES 857
#define PQCLEAN_SNTRUP857_AVX2_crypto_encode_857xfreeze3_ITEMS 857
#define PQCLEAN_SNTRUP857_AVX2_crypto_encode_857xfreeze3_ITEMBYTES 2

void PQCLEAN_SNTRUP857_AVX2_crypto_encode_857xfreeze3(unsigned char *s, const void *v);
#endif
