#ifndef PQCLEAN_NTRULPR653_AVX2_CRYPTO_VERIFY_1025_H
#define PQCLEAN_NTRULPR653_AVX2_CRYPTO_VERIFY_1025_H

#include <stdint.h>
#define PQCLEAN_NTRULPR653_AVX2_crypto_verify_1025_BYTES 1025

int PQCLEAN_NTRULPR653_AVX2_crypto_verify_1025(const unsigned char *x, const unsigned char *y);
#endif
