#ifndef PQCLEAN_NTRULPR953_AVX2_CRYPTO_DECODE_953X3_H
#define PQCLEAN_NTRULPR953_AVX2_CRYPTO_DECODE_953X3_H

#include <stdint.h>
#define PQCLEAN_NTRULPR953_AVX2_crypto_decode_953x3_STRBYTES 239
#define PQCLEAN_NTRULPR953_AVX2_crypto_decode_953x3_ITEMS 953
#define PQCLEAN_NTRULPR953_AVX2_crypto_decode_953x3_ITEMBYTES 1

void PQCLEAN_NTRULPR953_AVX2_crypto_decode_953x3(void *v, const unsigned char *s);
#endif
