#ifndef PQCLEAN_SNTRUP1277_CLEAN_CRYPTO_VERIFY_1847_H
#define PQCLEAN_SNTRUP1277_CLEAN_CRYPTO_VERIFY_1847_H

#include <stdint.h>
#define PQCLEAN_SNTRUP1277_CLEAN_crypto_verify_1847_BYTES 1847

int PQCLEAN_SNTRUP1277_CLEAN_crypto_verify_1847(const unsigned char *x, const unsigned char *y);
#endif
