#ifndef PQCLEAN_SNTRUP1013_CLEAN_CRYPTO_DECODE_1013X2393_H
#define PQCLEAN_SNTRUP1013_CLEAN_CRYPTO_DECODE_1013X2393_H

#include <stdint.h>
#define PQCLEAN_SNTRUP1013_CLEAN_crypto_decode_1013x2393_STRBYTES 1423
#define PQCLEAN_SNTRUP1013_CLEAN_crypto_decode_1013x2393_ITEMS 1013
#define PQCLEAN_SNTRUP1013_CLEAN_crypto_decode_1013x2393_ITEMBYTES 2

void PQCLEAN_SNTRUP1013_CLEAN_crypto_decode_1013x2393(void *v, const unsigned char *s);
#endif
