#ifndef PQCLEAN_SNTRUP1277_AVX2_CRYPTO_CORE_INVSNTRUP1277_H
#define PQCLEAN_SNTRUP1277_AVX2_CRYPTO_CORE_INVSNTRUP1277_H

#include <stdint.h>
#define PQCLEAN_SNTRUP1277_AVX2_crypto_core_invsntrup1277_OUTPUTBYTES 2555
#define PQCLEAN_SNTRUP1277_AVX2_crypto_core_invsntrup1277_INPUTBYTES 1277
#define PQCLEAN_SNTRUP1277_AVX2_crypto_core_invsntrup1277_KEYBYTES 0
#define PQCLEAN_SNTRUP1277_AVX2_crypto_core_invsntrup1277_CONSTBYTES 0

int PQCLEAN_SNTRUP1277_AVX2_crypto_core_invsntrup1277(unsigned char *outbytes, const unsigned char *inbytes);
#endif
