#ifndef PQCLEAN_SNTRUP653_AVX2_CRYPTO_DECODE_653X4621_H
#define PQCLEAN_SNTRUP653_AVX2_CRYPTO_DECODE_653X4621_H

#include <stdint.h>
#define PQCLEAN_SNTRUP653_AVX2_crypto_decode_653x4621_STRBYTES 994
#define PQCLEAN_SNTRUP653_AVX2_crypto_decode_653x4621_ITEMS 653
#define PQCLEAN_SNTRUP653_AVX2_crypto_decode_653x4621_ITEMBYTES 2

void PQCLEAN_SNTRUP653_AVX2_crypto_decode_653x4621(void *v, const unsigned char *s);
#endif
