#ifndef PQCLEAN_SNTRUP653_CLEAN_CRYPTO_DECODE_653XINT32_H
#define PQCLEAN_SNTRUP653_CLEAN_CRYPTO_DECODE_653XINT32_H

#include <stdint.h>
#define PQCLEAN_SNTRUP653_CLEAN_crypto_decode_653xint32_STRBYTES 2612
#define PQCLEAN_SNTRUP653_CLEAN_crypto_decode_653xint32_ITEMS 653
#define PQCLEAN_SNTRUP653_CLEAN_crypto_decode_653xint32_ITEMBYTES 4

void PQCLEAN_SNTRUP653_CLEAN_crypto_decode_653xint32(void *v, const unsigned char *s);
#endif
