#ifndef PQCLEAN_SNTRUP1013_CLEAN_CRYPTO_DECODE_1013X3_H
#define PQCLEAN_SNTRUP1013_CLEAN_CRYPTO_DECODE_1013X3_H

#include <stdint.h>
#define PQCLEAN_SNTRUP1013_CLEAN_crypto_decode_1013x3_STRBYTES 254
#define PQCLEAN_SNTRUP1013_CLEAN_crypto_decode_1013x3_ITEMS 1013
#define PQCLEAN_SNTRUP1013_CLEAN_crypto_decode_1013x3_ITEMBYTES 1

void PQCLEAN_SNTRUP1013_CLEAN_crypto_decode_1013x3(void *v, const unsigned char *s);
#endif
