#ifndef PQCLEAN_NTRULPR1277_AVX2_CRYPTO_DECODE_1277X3_H
#define PQCLEAN_NTRULPR1277_AVX2_CRYPTO_DECODE_1277X3_H

#include <stdint.h>
#define PQCLEAN_NTRULPR1277_AVX2_crypto_decode_1277x3_STRBYTES 320
#define PQCLEAN_NTRULPR1277_AVX2_crypto_decode_1277x3_ITEMS 1277
#define PQCLEAN_NTRULPR1277_AVX2_crypto_decode_1277x3_ITEMBYTES 1

void PQCLEAN_NTRULPR1277_AVX2_crypto_decode_1277x3(void *v, const unsigned char *s);
#endif
