#ifndef PQCLEAN_SNTRUP1277_CLEAN_CRYPTO_DECODE_1277XINT16_H
#define PQCLEAN_SNTRUP1277_CLEAN_CRYPTO_DECODE_1277XINT16_H

#include <stdint.h>
#define PQCLEAN_SNTRUP1277_CLEAN_crypto_decode_1277xint16_STRBYTES 2554
#define PQCLEAN_SNTRUP1277_CLEAN_crypto_decode_1277xint16_ITEMS 1277
#define PQCLEAN_SNTRUP1277_CLEAN_crypto_decode_1277xint16_ITEMBYTES 2

void PQCLEAN_SNTRUP1277_CLEAN_crypto_decode_1277xint16(void *v, const unsigned char *s);
#endif
