#ifndef PQCLEAN_SNTRUP1277_CLEAN_CRYPTO_DECODE_1277X2627_H
#define PQCLEAN_SNTRUP1277_CLEAN_CRYPTO_DECODE_1277X2627_H

#include <stdint.h>
#define PQCLEAN_SNTRUP1277_CLEAN_crypto_decode_1277x2627_STRBYTES 1815
#define PQCLEAN_SNTRUP1277_CLEAN_crypto_decode_1277x2627_ITEMS 1277
#define PQCLEAN_SNTRUP1277_CLEAN_crypto_decode_1277x2627_ITEMBYTES 2

void PQCLEAN_SNTRUP1277_CLEAN_crypto_decode_1277x2627(void *v, const unsigned char *s);
#endif
