#ifndef PQCLEAN_SNTRUP653_CLEAN_CRYPTO_CORE_INV3SNTRUP653_H
#define PQCLEAN_SNTRUP653_CLEAN_CRYPTO_CORE_INV3SNTRUP653_H

#include <stdint.h>
#define PQCLEAN_SNTRUP653_CLEAN_crypto_core_inv3sntrup653_OUTPUTBYTES 654
#define PQCLEAN_SNTRUP653_CLEAN_crypto_core_inv3sntrup653_INPUTBYTES 653
#define PQCLEAN_SNTRUP653_CLEAN_crypto_core_inv3sntrup653_KEYBYTES 0
#define PQCLEAN_SNTRUP653_CLEAN_crypto_core_inv3sntrup653_CONSTBYTES 0

int PQCLEAN_SNTRUP653_CLEAN_crypto_core_inv3sntrup653(unsigned char *outbytes, const unsigned char *inbytes);
#endif
