#ifndef PQCLEAN_MCELIECE460896F_CLEAN_PK_GEN_H
#define PQCLEAN_MCELIECE460896F_CLEAN_PK_GEN_H
/*
  This file is for public-key generation
*/


#include <stdint.h>

int PQCLEAN_MCELIECE460896F_CLEAN_pk_gen(uint8_t * /*pk*/, uint32_t * /*perm*/, const uint8_t * /*sk*/);

#endif

