#ifndef PQCLEAN_SNTRUP1277_CLEAN_CRYPTO_DECODE_1277X7879_H
#define PQCLEAN_SNTRUP1277_CLEAN_CRYPTO_DECODE_1277X7879_H

#include <stdint.h>
#define PQCLEAN_SNTRUP1277_CLEAN_crypto_decode_1277x7879_STRBYTES 2067
#define PQCLEAN_SNTRUP1277_CLEAN_crypto_decode_1277x7879_ITEMS 1277
#define PQCLEAN_SNTRUP1277_CLEAN_crypto_decode_1277x7879_ITEMBYTES 2

void PQCLEAN_SNTRUP1277_CLEAN_crypto_decode_1277x7879(void *v, const unsigned char *s);
#endif
