#ifndef PQCLEAN_NTRULPR857_AVX2_CRYPTO_DECODE_256X2_H
#define PQCLEAN_NTRULPR857_AVX2_CRYPTO_DECODE_256X2_H

#include <stdint.h>
#define PQCLEAN_NTRULPR857_AVX2_crypto_decode_256x2_STRBYTES 32
#define PQCLEAN_NTRULPR857_AVX2_crypto_decode_256x2_ITEMS 256
#define PQCLEAN_NTRULPR857_AVX2_crypto_decode_256x2_ITEMBYTES 1

void PQCLEAN_NTRULPR857_AVX2_crypto_decode_256x2(void *v, const unsigned char *s);
#endif
