#ifndef PQCLEAN_MCELIECE6688128F_CLEAN_TRANSPOSE_H
#define PQCLEAN_MCELIECE6688128F_CLEAN_TRANSPOSE_H
/*
  This file is for matrix transposition
*/


#include <stdint.h>

void PQCLEAN_MCELIECE6688128F_CLEAN_transpose_64x64(uint64_t * /*out*/, const uint64_t * /*in*/);

#endif

