#ifndef PQCLEAN_SNTRUP953_AVX2_CRYPTO_ENCODE_953X3_H
#define PQCLEAN_SNTRUP953_AVX2_CRYPTO_ENCODE_953X3_H

#include <stdint.h>
#define PQCLEAN_SNTRUP953_AVX2_crypto_encode_953x3_STRBYTES 239
#define PQCLEAN_SNTRUP953_AVX2_crypto_encode_953x3_ITEMS 953
#define PQCLEAN_SNTRUP953_AVX2_crypto_encode_953x3_ITEMBYTES 1

void PQCLEAN_SNTRUP953_AVX2_crypto_encode_953x3(unsigned char *s, const void *v);
#endif
