#ifndef PQCLEAN_MCELIECE348864F_CLEAN_BENES_H
#define PQCLEAN_MCELIECE348864F_CLEAN_BENES_H
/*
  This file is for Benes network related functions
*/


#include "gf.h"

void PQCLEAN_MCELIECE348864F_CLEAN_apply_benes(unsigned char * /*r*/, const unsigned char * /*bits*/, int /*rev*/);
void PQCLEAN_MCELIECE348864F_CLEAN_support_gen(gf * /*s*/, const unsigned char * /*c*/);

#endif

