#ifndef PQCLEAN_NTRULPR953_CLEAN_CRYPTO_VERIFY_1477_H
#define PQCLEAN_NTRULPR953_CLEAN_CRYPTO_VERIFY_1477_H

#include <stdint.h>
#define PQCLEAN_NTRULPR953_CLEAN_crypto_verify_1477_BYTES 1477

int PQCLEAN_NTRULPR953_CLEAN_crypto_verify_1477(const unsigned char *x, const unsigned char *y);
#endif
