#ifndef PQCLEAN_SNTRUP1013_CLEAN_CRYPTO_VERIFY_1455_H
#define PQCLEAN_SNTRUP1013_CLEAN_CRYPTO_VERIFY_1455_H

#include <stdint.h>
#define PQCLEAN_SNTRUP1013_CLEAN_crypto_verify_1455_BYTES 1455

int PQCLEAN_SNTRUP1013_CLEAN_crypto_verify_1455(const unsigned char *x, const unsigned char *y);
#endif
