#ifndef PQCLEAN_SNTRUP857_AVX2_CRYPTO_CORE_INV3SNTRUP857_H
#define PQCLEAN_SNTRUP857_AVX2_CRYPTO_CORE_INV3SNTRUP857_H

#include <stdint.h>
#define PQCLEAN_SNTRUP857_AVX2_crypto_core_inv3sntrup857_OUTPUTBYTES 858
#define PQCLEAN_SNTRUP857_AVX2_crypto_core_inv3sntrup857_INPUTBYTES 857
#define PQCLEAN_SNTRUP857_AVX2_crypto_core_inv3sntrup857_KEYBYTES 0
#define PQCLEAN_SNTRUP857_AVX2_crypto_core_inv3sntrup857_CONSTBYTES 0

int PQCLEAN_SNTRUP857_AVX2_crypto_core_inv3sntrup857(unsigned char *outbytes, const unsigned char *inbytes);
#endif
