#ifndef PQCLEAN_NTRULPR857_AVX2_CRYPTO_VERIFY_1312_H
#define PQCLEAN_NTRULPR857_AVX2_CRYPTO_VERIFY_1312_H

#include <stdint.h>
#define PQCLEAN_NTRULPR857_AVX2_crypto_verify_1312_BYTES 1312

int PQCLEAN_NTRULPR857_AVX2_crypto_verify_1312(const unsigned char *x, const unsigned char *y);
#endif
