#ifndef PQCLEAN_SNTRUP953_CLEAN_CRYPTO_VERIFY_1349_H
#define PQCLEAN_SNTRUP953_CLEAN_CRYPTO_VERIFY_1349_H

#include <stdint.h>
#define PQCLEAN_SNTRUP953_CLEAN_crypto_verify_1349_BYTES 1349

int PQCLEAN_SNTRUP953_CLEAN_crypto_verify_1349(const unsigned char *x, const unsigned char *y);
#endif
