#ifndef PQCLEAN_SNTRUP953_AVX2_CRYPTO_CORE_SCALE3SNTRUP953_H
#define PQCLEAN_SNTRUP953_AVX2_CRYPTO_CORE_SCALE3SNTRUP953_H

#include <stdint.h>
#define PQCLEAN_SNTRUP953_AVX2_crypto_core_scale3sntrup953_OUTPUTBYTES 1906
#define PQCLEAN_SNTRUP953_AVX2_crypto_core_scale3sntrup953_INPUTBYTES 1906
#define PQCLEAN_SNTRUP953_AVX2_crypto_core_scale3sntrup953_KEYBYTES 0
#define PQCLEAN_SNTRUP953_AVX2_crypto_core_scale3sntrup953_CONSTBYTES 0

int PQCLEAN_SNTRUP953_AVX2_crypto_core_scale3sntrup953(unsigned char *outbytes, const unsigned char *inbytes);
#endif
