#ifndef PQCLEAN_SNTRUP1013_AVX2_CRYPTO_DECODE_1013XINT16_H
#define PQCLEAN_SNTRUP1013_AVX2_CRYPTO_DECODE_1013XINT16_H

#include <stdint.h>
#define PQCLEAN_SNTRUP1013_AVX2_crypto_decode_1013xint16_STRBYTES 2026
#define PQCLEAN_SNTRUP1013_AVX2_crypto_decode_1013xint16_ITEMS 1013
#define PQCLEAN_SNTRUP1013_AVX2_crypto_decode_1013xint16_ITEMBYTES 2

void PQCLEAN_SNTRUP1013_AVX2_crypto_decode_1013xint16(void *v, const unsigned char *s);
#endif
