#ifndef PQCLEAN_SNTRUP761_AVX2_CRYPTO_DECODE_761X3_H
#define PQCLEAN_SNTRUP761_AVX2_CRYPTO_DECODE_761X3_H

#include <stdint.h>
#define PQCLEAN_SNTRUP761_AVX2_crypto_decode_761x3_STRBYTES 191
#define PQCLEAN_SNTRUP761_AVX2_crypto_decode_761x3_ITEMS 761
#define PQCLEAN_SNTRUP761_AVX2_crypto_decode_761x3_ITEMBYTES 1

void PQCLEAN_SNTRUP761_AVX2_crypto_decode_761x3(void *v, const unsigned char *s);
#endif
