#ifndef PQCLEAN_NTRULPR953_AVX2_CRYPTO_DECODE_953X2115_H
#define PQCLEAN_NTRULPR953_AVX2_CRYPTO_DECODE_953X2115_H

#include <stdint.h>
#define PQCLEAN_NTRULPR953_AVX2_crypto_decode_953x2115_STRBYTES 1317
#define PQCLEAN_NTRULPR953_AVX2_crypto_decode_953x2115_ITEMS 953
#define PQCLEAN_NTRULPR953_AVX2_crypto_decode_953x2115_ITEMBYTES 2

void PQCLEAN_NTRULPR953_AVX2_crypto_decode_953x2115(void *v, const unsigned char *s);
#endif
