#ifndef PQCLEAN_SNTRUP1277_CLEAN_CRYPTO_CORE_MULT3SNTRUP1277_H
#define PQCLEAN_SNTRUP1277_CLEAN_CRYPTO_CORE_MULT3SNTRUP1277_H

#include <stdint.h>
#define PQCLEAN_SNTRUP1277_CLEAN_crypto_core_mult3sntrup1277_OUTPUTBYTES 1277
#define PQCLEAN_SNTRUP1277_CLEAN_crypto_core_mult3sntrup1277_INPUTBYTES 1277
#define PQCLEAN_SNTRUP1277_CLEAN_crypto_core_mult3sntrup1277_KEYBYTES 1277
#define PQCLEAN_SNTRUP1277_CLEAN_crypto_core_mult3sntrup1277_CONSTBYTES 0

int PQCLEAN_SNTRUP1277_CLEAN_crypto_core_mult3sntrup1277(unsigned char *outbytes, const unsigned char *inbytes, const unsigned char *kbytes);
#endif
