#ifndef PQCLEAN_NTRULPR1277_CLEAN_CRYPTO_DECODE_256X16_H
#define PQCLEAN_NTRULPR1277_CLEAN_CRYPTO_DECODE_256X16_H

#include <stdint.h>
#define PQCLEAN_NTRULPR1277_CLEAN_crypto_decode_256x16_STRBYTES 128
#define PQCLEAN_NTRULPR1277_CLEAN_crypto_decode_256x16_ITEMS 256
#define PQCLEAN_NTRULPR1277_CLEAN_crypto_decode_256x16_ITEMBYTES 1

void PQCLEAN_NTRULPR1277_CLEAN_crypto_decode_256x16(void *v, const unsigned char *s);
#endif
