.data
.p2align 5
mask_0_1:
.byte 0
.byte 6
.byte 12
.byte 255
.byte 255
.byte 4
.byte 255
.byte 11
.byte 255
.byte 255
.byte 4
.byte 10
.byte 255
.byte 255
.byte 3
.byte 9
.byte 255
.byte 0
.byte 6
.byte 255
.byte 13
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 4
.byte 10
.byte 255
.byte 255
.byte 3

mask_1_1:
.word 0x801
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8010
.word 0x400
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000

mask_2_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1002
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x0

mask_3_1:
.word 0x0
.word 0x0
.word 0x4000
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_4_1:
.byte 255
.byte 10
.byte 255
.byte 255
.byte 3
.byte 9
.byte 15
.byte 255
.byte 1
.byte 7
.byte 255
.byte 14
.byte 0
.byte 255
.byte 7
.byte 13
.byte 255
.byte 255
.byte 1
.byte 255
.byte 8
.byte 14
.byte 255
.byte 1
.byte 7
.byte 255
.byte 14
.byte 0
.byte 255
.byte 7
.byte 13
.byte 255

mask_5_1:
.word 0x0
.word 0x0
.word 0x1002
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2000
.word 0x100
.word 0x8

mask_6_1:
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x20
.word 0x1
.word 0x0
.word 0x0

mask_7_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8010
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_8_1:
.byte 9
.byte 15
.byte 255
.byte 1
.byte 7
.byte 255
.byte 14
.byte 0
.byte 255
.byte 7
.byte 13
.byte 255
.byte 255
.byte 6
.byte 12
.byte 255
.byte 3
.byte 9
.byte 15
.byte 255
.byte 1
.byte 7
.byte 255
.byte 14
.byte 0
.byte 255
.byte 7
.byte 13
.byte 255
.byte 0
.byte 6
.byte 255

mask_9_1:
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x1002
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x20

mask_10_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x2000
.word 0x100
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x2004
.word 0x0
.word 0x0

mask_11_1:
.word 0x0
.word 0x400
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8010
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_12_1:
.byte 13
.byte 255
.byte 255
.byte 6
.byte 12
.byte 255
.byte 255
.byte 4
.byte 10
.byte 255
.byte 255
.byte 3
.byte 255
.byte 10
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 11
.byte 255
.byte 255
.byte 4
.byte 10
.byte 255
.byte 255
.byte 3
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255

mask_13_1:
.word 0x0
.word 0x100
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8010
.word 0x0
.word 0x0

mask_14_1:
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1002
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_15_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_16_1:
.byte 255
.byte 255
.byte 4
.byte 10
.byte 255
.byte 255
.byte 3
.byte 9
.byte 255
.byte 255
.byte 2
.byte 255
.byte 9
.byte 15
.byte 255
.byte 1
.byte 12
.byte 255
.byte 255
.byte 4
.byte 10
.byte 255
.byte 255
.byte 3
.byte 255
.byte 10
.byte 255
.byte 255
.byte 3
.byte 9
.byte 15
.byte 255

mask_17_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x2004
.word 0x0
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1002
.word 0x80

mask_18_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x8010
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x200
.word 0x0
.word 0x0
.word 0x0

mask_19_1:
.word 0x0
.word 0x1002
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x0
.word 0x800
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_20_1:
.byte 2
.byte 8
.byte 255
.byte 15
.byte 0
.byte 255
.byte 7
.byte 13
.byte 255
.byte 0
.byte 6
.byte 255
.byte 13
.byte 255
.byte 255
.byte 6
.byte 7
.byte 255
.byte 14
.byte 0
.byte 255
.byte 7
.byte 13
.byte 255
.byte 255
.byte 6
.byte 12
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_21_1:
.word 0x8010
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x0
.word 0x0

mask_22_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x2000
.word 0x100
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_23_1:
.word 0x0
.word 0x0
.word 0x80
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_24_1:
.byte 255
.byte 7
.byte 13
.byte 255
.byte 255
.byte 6
.byte 12
.byte 255
.byte 255
.byte 5
.byte 255
.byte 12
.byte 255
.byte 255
.byte 4
.byte 10
.byte 0
.byte 255
.byte 7
.byte 13
.byte 255
.byte 0
.byte 6
.byte 255
.byte 13
.byte 255
.byte 255
.byte 6
.byte 12
.byte 255
.byte 255
.byte 255

mask_25_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x8
.word 0x0

mask_26_1:
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0

mask_27_1:
.word 0x100
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1002
.word 0x80
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_28_1:
.byte 11
.byte 255
.byte 255
.byte 3
.byte 255
.byte 10
.byte 255
.byte 255
.byte 3
.byte 9
.byte 15
.byte 255
.byte 2
.byte 8
.byte 255
.byte 15
.byte 255
.byte 255
.byte 3
.byte 9
.byte 255
.byte 255
.byte 2
.byte 255
.byte 9
.byte 15
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0

mask_29_1:
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8010
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x2004
.word 0x0
.word 0x0
.word 0x0

mask_30_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1002
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x8010
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2000

mask_31_1:
.word 0x0
.word 0x4000
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_32_1:
.byte 255
.byte 255
.byte 2
.byte 255
.byte 9
.byte 15
.byte 255
.byte 2
.byte 8
.byte 255
.byte 15
.byte 0
.byte 255
.byte 7
.byte 13
.byte 255
.byte 255
.byte 10
.byte 255
.byte 255
.byte 3
.byte 9
.byte 15
.byte 255
.byte 2
.byte 8
.byte 255
.byte 15
.byte 255
.byte 255
.byte 255
.byte 255

mask_33_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8010
.word 0x400
.word 0x0
.word 0x0

mask_34_1:
.word 0x0
.word 0x80
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1002
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_35_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2000
.word 0x100
.word 0x8
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_36_1:
.byte 255
.byte 0
.byte 6
.byte 255
.byte 13
.byte 255
.byte 255
.byte 6
.byte 12
.byte 255
.byte 255
.byte 5
.byte 11
.byte 255
.byte 255
.byte 3
.byte 255
.byte 6
.byte 12
.byte 255
.byte 255
.byte 5
.byte 255
.byte 12
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 9

mask_37_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_38_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8010

mask_39_1:
.word 0x400
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_40_1:
.byte 255
.byte 5
.byte 255
.byte 12
.byte 255
.byte 255
.byte 5
.byte 11
.byte 255
.byte 255
.byte 3
.byte 9
.byte 255
.byte 255
.byte 2
.byte 255
.byte 13
.byte 255
.byte 255
.byte 6
.byte 12
.byte 255
.byte 255
.byte 5
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_41_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x1002
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x0
.word 0x0
.word 0x0

mask_42_1:
.word 0x4000
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x100
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_43_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8010
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_44_1:
.byte 3
.byte 9
.byte 15
.byte 255
.byte 2
.byte 8
.byte 255
.byte 15
.byte 1
.byte 255
.byte 8
.byte 14
.byte 255
.byte 0
.byte 6
.byte 255
.byte 9
.byte 15
.byte 255
.byte 2
.byte 8
.byte 255
.byte 15
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 6
.byte 12
.byte 255

mask_45_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_46_1:
.word 0x0
.word 0x0
.word 0x8010
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40

mask_47_1:
.word 0x1002
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_48_1:
.byte 8
.byte 255
.byte 15
.byte 1
.byte 255
.byte 8
.byte 14
.byte 255
.byte 255
.byte 6
.byte 12
.byte 255
.byte 255
.byte 5
.byte 255
.byte 12
.byte 2
.byte 8
.byte 255
.byte 15
.byte 1
.byte 255
.byte 8
.byte 14
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 6

mask_49_1:
.word 0x0
.word 0x2000
.word 0x100
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_50_1:
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x200
.word 0x8010
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100

mask_51_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_52_1:
.byte 12
.byte 255
.byte 255
.byte 5
.byte 11
.byte 255
.byte 255
.byte 4
.byte 255
.byte 11
.byte 255
.byte 255
.byte 3
.byte 9
.byte 15
.byte 255
.byte 255
.byte 255
.byte 5
.byte 11
.byte 255
.byte 255
.byte 3
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 9
.byte 15
.byte 255
.byte 2

mask_53_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1002
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400

mask_54_1:
.word 0x0
.word 0x800
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x2004
.word 0x0

mask_55_1:
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1002
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_56_1:
.byte 255
.byte 255
.byte 4
.byte 10
.byte 255
.byte 255
.byte 2
.byte 255
.byte 9
.byte 15
.byte 255
.byte 2
.byte 8
.byte 255
.byte 15
.byte 1
.byte 11
.byte 255
.byte 255
.byte 4
.byte 255
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 8
.byte 255
.byte 15

mask_57_1:
.word 0x0
.word 0x8010
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2000
.word 0x0
.word 0x4000
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_58_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x20
.word 0x1
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8010
.word 0x400

mask_59_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_60_1:
.byte 1
.byte 255
.byte 8
.byte 14
.byte 255
.byte 1
.byte 7
.byte 255
.byte 14
.byte 255
.byte 255
.byte 6
.byte 12
.byte 255
.byte 255
.byte 5
.byte 255
.byte 8
.byte 14
.byte 255
.byte 255
.byte 6
.byte 12
.byte 255
.byte 255
.byte 5
.byte 255
.byte 12
.byte 255
.byte 255
.byte 5
.byte 11

mask_61_1:
.word 0x0
.word 0x0
.word 0x400
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1002

mask_62_1:
.word 0x80
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x200
.word 0x0
.word 0x0

mask_63_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_64_1:
.byte 13
.byte 255
.byte 0
.byte 6
.byte 255
.byte 13
.byte 255
.byte 255
.byte 6
.byte 12
.byte 255
.byte 255
.byte 4
.byte 255
.byte 11
.byte 255
.byte 7
.byte 255
.byte 14
.byte 0
.byte 255
.byte 7
.byte 13
.byte 255
.byte 0
.byte 6
.byte 12
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_65_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1002
.word 0x80
.word 0x0
.word 0x0

mask_66_1:
.word 0x0
.word 0x8010
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x200
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_67_1:
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x1
.word 0x40
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_68_1:
.byte 255
.byte 255
.byte 4
.byte 10
.byte 255
.byte 255
.byte 3
.byte 255
.byte 10
.byte 255
.byte 255
.byte 3
.byte 9
.byte 15
.byte 255
.byte 1
.byte 255
.byte 4
.byte 10
.byte 255
.byte 255
.byte 3
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 7

mask_69_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x4008
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_70_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1002

mask_71_1:
.word 0x0
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_72_1:
.byte 255
.byte 3
.byte 9
.byte 255
.byte 255
.byte 2
.byte 255
.byte 9
.byte 15
.byte 255
.byte 1
.byte 7
.byte 13
.byte 255
.byte 0
.byte 6
.byte 255
.byte 255
.byte 3
.byte 255
.byte 10
.byte 255
.byte 255
.byte 3
.byte 9
.byte 15
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0

mask_73_1:
.word 0x0
.word 0x0
.word 0x4000
.word 0x200
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x4008
.word 0x0
.word 0x0
.word 0x0

mask_74_1:
.word 0x800
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8010
.word 0x0
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000

mask_75_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1002
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_76_1:
.byte 255
.byte 7
.byte 13
.byte 255
.byte 0
.byte 6
.byte 12
.byte 255
.byte 255
.byte 5
.byte 255
.byte 12
.byte 255
.byte 255
.byte 4
.byte 10
.byte 255
.byte 13
.byte 255
.byte 255
.byte 6
.byte 12
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 10
.byte 255

mask_77_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_78_1:
.word 0x0
.word 0x0
.word 0x1002
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x8

mask_79_1:
.word 0x200
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_80_1:
.byte 6
.byte 12
.byte 255
.byte 255
.byte 5
.byte 255
.byte 12
.byte 255
.byte 255
.byte 4
.byte 10
.byte 255
.byte 255
.byte 3
.byte 9
.byte 255
.byte 0
.byte 6
.byte 12
.byte 255
.byte 255
.byte 5
.byte 255
.byte 12
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255

mask_81_1:
.word 0x0
.word 0x0
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_82_1:
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x1002
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20

mask_83_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_84_1:
.byte 10
.byte 255
.byte 255
.byte 3
.byte 9
.byte 15
.byte 255
.byte 2
.byte 8
.byte 255
.byte 15
.byte 0
.byte 255
.byte 7
.byte 13
.byte 255
.byte 255
.byte 2
.byte 255
.byte 9
.byte 15
.byte 255
.byte 1
.byte 7
.byte 255
.byte 255
.byte 0
.byte 6
.byte 255
.byte 13
.byte 255
.byte 255

mask_85_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x2
.word 0x0
.word 0x0
.word 0x4000
.word 0x200
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_86_1:
.word 0x0
.word 0x100
.word 0x4008
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8010
.word 0x400
.word 0x0

mask_87_1:
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x200
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x1002
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_88_1:
.byte 15
.byte 255
.byte 2
.byte 8
.byte 14
.byte 255
.byte 0
.byte 6
.byte 255
.byte 13
.byte 255
.byte 255
.byte 6
.byte 12
.byte 255
.byte 255
.byte 9
.byte 15
.byte 255
.byte 2
.byte 8
.byte 255
.byte 15
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 6
.byte 12
.byte 255

mask_89_1:
.word 0x0
.word 0x1002
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_90_1:
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2004
.word 0x0
.word 0x4008
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1002
.word 0x80

mask_91_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x8010
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_92_1:
.byte 255
.byte 5
.byte 255
.byte 12
.byte 255
.byte 255
.byte 5
.byte 11
.byte 255
.byte 255
.byte 3
.byte 255
.byte 10
.byte 255
.byte 255
.byte 3
.byte 5
.byte 255
.byte 12
.byte 255
.byte 255
.byte 4
.byte 10
.byte 255
.byte 255
.byte 3
.byte 9
.byte 255
.byte 255
.byte 2
.byte 255
.byte 9

mask_93_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x200

mask_94_1:
.word 0x8000
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x0
.word 0x0

mask_95_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_96_1:
.byte 255
.byte 5
.byte 11
.byte 255
.byte 255
.byte 3
.byte 9
.byte 255
.byte 255
.byte 2
.byte 255
.byte 9
.byte 15
.byte 255
.byte 2
.byte 8
.byte 255
.byte 255
.byte 5
.byte 11
.byte 255
.byte 255
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 9
.byte 15
.byte 255
.byte 2

mask_97_1:
.word 0x100
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1002
.word 0x0
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800

mask_98_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x200
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x4008
.word 0x0

mask_99_1:
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_100_1:
.byte 8
.byte 255
.byte 15
.byte 1
.byte 255
.byte 8
.byte 14
.byte 255
.byte 0
.byte 6
.byte 12
.byte 255
.byte 255
.byte 5
.byte 255
.byte 12
.byte 14
.byte 255
.byte 0
.byte 6
.byte 255
.byte 13
.byte 255
.byte 255
.byte 6
.byte 12
.byte 255
.byte 255
.byte 5
.byte 255
.byte 12
.byte 255

mask_101_1:
.word 0x0
.word 0x4000
.word 0x200
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x1

mask_102_1:
.word 0x40
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2004
.word 0x0
.word 0x0
.word 0x0

mask_103_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1002
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x8010
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_104_1:
.byte 255
.byte 14
.byte 255
.byte 255
.byte 6
.byte 12
.byte 255
.byte 255
.byte 5
.byte 255
.byte 12
.byte 255
.byte 255
.byte 5
.byte 11
.byte 255
.byte 255
.byte 8
.byte 14
.byte 255
.byte 0
.byte 6
.byte 12
.byte 255
.byte 255
.byte 5
.byte 255
.byte 12
.byte 255
.byte 255
.byte 5
.byte 11

mask_105_1:
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x8
.word 0x200
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2004

mask_106_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x400
.word 0x0
.word 0x0

mask_107_1:
.word 0x0
.word 0x0
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1002
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_108_1:
.byte 255
.byte 255
.byte 4
.byte 255
.byte 11
.byte 255
.byte 255
.byte 3
.byte 9
.byte 15
.byte 255
.byte 2
.byte 8
.byte 255
.byte 15
.byte 1
.byte 255
.byte 3
.byte 9
.byte 255
.byte 255
.byte 2
.byte 255
.byte 9
.byte 15
.byte 255
.byte 2
.byte 8
.byte 14
.byte 255
.byte 255
.byte 255

mask_109_1:
.word 0x0
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1002
.word 0x80
.word 0x0

mask_110_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x2
.word 0x0
.word 0x0
.word 0x4000
.word 0x200
.word 0x10
.word 0x0
.word 0x0
.word 0x0

mask_111_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x4008
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_112_1:
.byte 255
.byte 2
.byte 255
.byte 9
.byte 15
.byte 255
.byte 2
.byte 8
.byte 14
.byte 255
.byte 1
.byte 7
.byte 255
.byte 14
.byte 255
.byte 255
.byte 11
.byte 255
.byte 255
.byte 3
.byte 9
.byte 15
.byte 255
.byte 2
.byte 8
.byte 255
.byte 15
.byte 1
.byte 255
.byte 8
.byte 14
.byte 255

mask_113_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8010
.word 0x400
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x200
.word 0x10

mask_114_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x1002
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x2
.word 0x0
.word 0x0

mask_115_1:
.word 0x4000
.word 0x200
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x4008
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_116_1:
.byte 1
.byte 7
.byte 13
.byte 255
.byte 255
.byte 5
.byte 255
.byte 12
.byte 255
.byte 255
.byte 5
.byte 11
.byte 255
.byte 255
.byte 4
.byte 255
.byte 6
.byte 12
.byte 255
.byte 255
.byte 5
.byte 255
.byte 12
.byte 255
.byte 255
.byte 5
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_117_1:
.word 0x1002
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x8
.word 0x0
.word 0x0

mask_118_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_119_1:
.word 0x0
.word 0x0
.word 0x8000
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_120_1:
.byte 5
.byte 0
.byte 12
.byte 255
.byte 255
.byte 5
.byte 11
.byte 255
.byte 255
.byte 4
.byte 10
.byte 255
.byte 255
.byte 2
.byte 255
.byte 9
.byte 255
.byte 5
.byte 255
.byte 12
.byte 255
.byte 255
.byte 5
.byte 11
.byte 255
.byte 255
.byte 4
.byte 255
.byte 11
.byte 255
.byte 255
.byte 255

mask_121_1:
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x1
.word 0x0

mask_122_1:
.word 0x0
.word 0x0
.word 0x100
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_123_1:
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x200
.word 0x8000
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_124_1:
.byte 10
.byte 255
.byte 255
.byte 2
.byte 8
.byte 255
.byte 15
.byte 1
.byte 255
.byte 8
.byte 14
.byte 255
.byte 1
.byte 7
.byte 13
.byte 255
.byte 15
.byte 255
.byte 2
.byte 8
.byte 14
.byte 255
.byte 1
.byte 7
.byte 255
.byte 14
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_125_1:
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1002
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x8010
.word 0x400
.word 0x0
.word 0x0
.word 0x0

mask_126_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x200
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x1002
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_127_1:
.word 0x0
.word 0x800
.word 0x40
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_128_1:
.byte 2
.byte 255
.byte 9
.byte 15
.byte 255
.byte 1
.byte 7
.byte 13
.byte 255
.byte 0
.byte 6
.byte 255
.byte 13
.byte 255
.byte 255
.byte 6
.byte 255
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 7
.byte 255
.byte 255
.byte 0

mask_129_1:
.word 0x20
.word 0x801
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100

mask_130_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x1
.word 0x0

mask_131_1:
.word 0x0
.word 0x0
.word 0x100
.word 0x4008
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_132_1:
.byte 6
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 255
.byte 12
.byte 255
.byte 255
.byte 4
.byte 10
.byte 255
.byte 255
.byte 3
.byte 255
.byte 10
.byte 255
.byte 255
.byte 3
.byte 9
.byte 255
.byte 255

mask_133_1:
.word 0x0
.word 0x0
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2004
.word 0x0

mask_134_1:
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x400
.word 0x0
.word 0x0
.word 0x0

mask_135_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_136_1:
.byte 11
.byte 255
.byte 255
.byte 3
.byte 255
.byte 10
.byte 255
.byte 255
.byte 3
.byte 9
.byte 255
.byte 255
.byte 2
.byte 255
.byte 9
.byte 15
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 255

mask_137_1:
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x801
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0

mask_138_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x0

mask_139_1:
.word 0x0
.word 0x8000
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_140_1:
.byte 255
.byte 255
.byte 2
.byte 255
.byte 255
.byte 255
.byte 0
.byte 255
.byte 7
.byte 255
.byte 255
.byte 0
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 7
.byte 13
.byte 255
.byte 0
.byte 6
.byte 255
.byte 13
.byte 255
.byte 255
.byte 6
.byte 12
.byte 255
.byte 255
.byte 255

mask_141_1:
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x10
.word 0x0

mask_142_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x2
.word 0x0
.word 0x0
.word 0x0

mask_143_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x4008
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_144_1:
.byte 255
.byte 0
.byte 6
.byte 255
.byte 13
.byte 255
.byte 255
.byte 6
.byte 12
.byte 255
.byte 255
.byte 5
.byte 11
.byte 255
.byte 255
.byte 3
.byte 255
.byte 255
.byte 0
.byte 255
.byte 7
.byte 255
.byte 255
.byte 0
.byte 6
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255

mask_145_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x40
.word 0x0

mask_146_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x8
.word 0x0
.word 0x0
.word 0x0

mask_147_1:
.word 0x800
.word 0x40
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_148_1:
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 255
.byte 10
.byte 255
.byte 255
.byte 3
.byte 9
.byte 255
.byte 255
.byte 2
.byte 255
.byte 9
.byte 15
.byte 255
.byte 255
.byte 255
.byte 255

mask_149_1:
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x801
.word 0x0
.word 0x0

mask_150_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_151_1:
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_152_1:
.byte 3
.byte 9
.byte 255
.byte 255
.byte 2
.byte 255
.byte 9
.byte 15
.byte 255
.byte 2
.byte 8
.byte 14
.byte 255
.byte 0
.byte 6
.byte 255
.byte 255
.byte 3
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_153_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x4008
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0

mask_154_1:
.word 0x0
.word 0x0
.word 0x20
.word 0x801
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_155_1:
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_156_1:
.byte 255
.byte 255
.byte 255
.byte 0
.byte 6
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 13
.byte 255
.byte 255
.byte 6
.byte 12
.byte 255
.byte 255
.byte 5
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_157_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x80
.word 0x0
.word 0x0
.word 0x0

mask_158_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_159_1:
.word 0x0
.word 0x100
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_160_1:
.byte 12
.byte 255
.byte 255
.byte 5
.byte 11
.byte 255
.byte 255
.byte 4
.byte 255
.byte 11
.byte 255
.byte 255
.byte 3
.byte 9
.byte 255
.byte 255
.byte 6
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_161_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0

mask_162_1:
.word 0x0
.word 0x1000
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_163_1:
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2004
.word 0x0
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_164_1:
.byte 255
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 8
.byte 255
.byte 255
.byte 0
.byte 2
.byte 255
.byte 9
.byte 15
.byte 255
.byte 2
.byte 8
.byte 14
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 6

mask_165_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x4008
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_166_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x801
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200

mask_167_1:
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_168_1:
.byte 255
.byte 2
.byte 8
.byte 14
.byte 255
.byte 1
.byte 7
.byte 255
.byte 14
.byte 255
.byte 255
.byte 6
.byte 12
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 2
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_169_1:
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0

mask_170_1:
.word 0x100
.word 0x4008
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_171_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_172_1:
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 255
.byte 11
.byte 255
.byte 255
.byte 4
.byte 255
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 9
.byte 15

mask_173_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_174_1:
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x801

mask_175_1:
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_176_1:
.byte 255
.byte 11
.byte 255
.byte 255
.byte 4
.byte 10
.byte 255
.byte 255
.byte 2
.byte 255
.byte 9
.byte 15
.byte 255
.byte 2
.byte 8
.byte 14
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255

mask_177_1:
.word 0x0
.word 0x0
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_178_1:
.word 0x400
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x4008
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4

mask_179_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x801
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_180_1:
.byte 255
.byte 255
.byte 1
.byte 255
.byte 8
.byte 255
.byte 255
.byte 1
.byte 7
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 7
.byte 255
.byte 14
.byte 255
.byte 255
.byte 6
.byte 255
.byte 255
.byte 255
.byte 5
.byte 11
.byte 255
.byte 255
.byte 4

mask_181_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000

mask_182_1:
.word 0x0
.word 0x20
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x80
.word 0x0

mask_183_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_184_1:
.byte 14
.byte 255
.byte 255
.byte 7
.byte 13
.byte 255
.byte 255
.byte 5
.byte 11
.byte 255
.byte 255
.byte 4
.byte 255
.byte 11
.byte 255
.byte 255
.byte 8
.byte 255
.byte 255
.byte 1
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255

mask_185_1:
.word 0x0
.word 0x200
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_186_1:
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x400
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0

mask_187_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_188_1:
.byte 255
.byte 4
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 2
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 4
.byte 10
.byte 255
.byte 255
.byte 2
.byte 255
.byte 9
.byte 15
.byte 255
.byte 2
.byte 8
.byte 14
.byte 255
.byte 1
.byte 7
.byte 255

mask_189_1:
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2004
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x40

mask_190_1:
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x4008
.word 0x0
.word 0x0

mask_191_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x801
.word 0x0
.word 0x0
.word 0x0
.word 0x0

.text
.global PQCLEAN_NTRUHRSS701_AVX2_square_84_701
.global _PQCLEAN_NTRUHRSS701_AVX2_square_84_701
PQCLEAN_NTRUHRSS701_AVX2_square_84_701:
_PQCLEAN_NTRUHRSS701_AVX2_square_84_701:
vmovdqa 0(%rsi), %ymm0
vpshufb mask_0_1(%rip), %ymm0, %ymm5
vpand mask_1_1(%rip), %ymm5, %ymm1
vpand mask_2_1(%rip), %ymm5, %ymm2
vpand mask_3_1(%rip), %ymm5, %ymm3
vpermq $78, %ymm0, %ymm8
vpshufb mask_4_1(%rip), %ymm8, %ymm5
vpand mask_5_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_6_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_7_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsllq $1, %ymm0, %ymm6
vpshufb mask_8_1(%rip), %ymm6, %ymm5
vpand mask_9_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_10_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_11_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm6, %ymm8
vpshufb mask_12_1(%rip), %ymm8, %ymm5
vpand mask_13_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_14_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_15_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsllq $2, %ymm0, %ymm6
vpshufb mask_16_1(%rip), %ymm6, %ymm5
vpand mask_17_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_18_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_19_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm6, %ymm8
vpshufb mask_20_1(%rip), %ymm8, %ymm5
vpand mask_21_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_22_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_23_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $61, %ymm0, %ymm5
vpsllq $3, %ymm0, %ymm4
vpermq $147, %ymm5, %ymm6
vpxor %ymm4, %ymm6, %ymm6
vpshufb mask_24_1(%rip), %ymm6, %ymm5
vpand mask_25_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_26_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_27_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm6, %ymm8
vpshufb mask_28_1(%rip), %ymm8, %ymm5
vpand mask_29_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_30_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_31_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsllq $1, %ymm6, %ymm7
vpshufb mask_32_1(%rip), %ymm7, %ymm5
vpand mask_33_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_34_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_35_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm8
vpshufb mask_36_1(%rip), %ymm8, %ymm5
vpand mask_37_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_38_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_39_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsllq $2, %ymm6, %ymm7
vpshufb mask_40_1(%rip), %ymm7, %ymm5
vpand mask_41_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_42_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_43_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm8
vpshufb mask_44_1(%rip), %ymm8, %ymm5
vpand mask_45_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_46_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_47_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $61, %ymm6, %ymm5
vpsllq $3, %ymm6, %ymm4
vpermq $147, %ymm5, %ymm7
vpxor %ymm4, %ymm7, %ymm7
vpshufb mask_48_1(%rip), %ymm7, %ymm5
vpand mask_49_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_50_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_51_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm8
vpshufb mask_52_1(%rip), %ymm8, %ymm5
vpand mask_53_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_54_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_55_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $63, %ymm7, %ymm5
vpsllq $1, %ymm7, %ymm4
vpermq $147, %ymm5, %ymm6
vpxor %ymm4, %ymm6, %ymm6
vpshufb mask_56_1(%rip), %ymm6, %ymm5
vpand mask_57_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_58_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_59_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm6, %ymm8
vpshufb mask_60_1(%rip), %ymm8, %ymm5
vpand mask_61_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_62_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_63_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vmovdqa 32(%rsi), %ymm0
vpshufb mask_64_1(%rip), %ymm0, %ymm5
vpand mask_65_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_66_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_67_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm0, %ymm8
vpshufb mask_68_1(%rip), %ymm8, %ymm5
vpand mask_69_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_70_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_71_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsllq $1, %ymm0, %ymm6
vpshufb mask_72_1(%rip), %ymm6, %ymm5
vpand mask_73_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_74_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_75_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm6, %ymm8
vpshufb mask_76_1(%rip), %ymm8, %ymm5
vpand mask_77_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_78_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_79_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $62, %ymm0, %ymm5
vpsllq $2, %ymm0, %ymm4
vpermq $147, %ymm5, %ymm6
vpxor %ymm4, %ymm6, %ymm6
vpshufb mask_80_1(%rip), %ymm6, %ymm5
vpand mask_81_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_82_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_83_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm6, %ymm8
vpshufb mask_84_1(%rip), %ymm8, %ymm5
vpand mask_85_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_86_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_87_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsllq $1, %ymm6, %ymm7
vpshufb mask_88_1(%rip), %ymm7, %ymm5
vpand mask_89_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_90_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_91_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm8
vpshufb mask_92_1(%rip), %ymm8, %ymm5
vpand mask_93_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_94_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_95_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $62, %ymm6, %ymm5
vpsllq $2, %ymm6, %ymm4
vpermq $147, %ymm5, %ymm7
vpxor %ymm4, %ymm7, %ymm7
vpshufb mask_96_1(%rip), %ymm7, %ymm5
vpand mask_97_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_98_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_99_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm8
vpshufb mask_100_1(%rip), %ymm8, %ymm5
vpand mask_101_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_102_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_103_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsllq $1, %ymm7, %ymm6
vpshufb mask_104_1(%rip), %ymm6, %ymm5
vpand mask_105_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_106_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_107_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm6, %ymm8
vpshufb mask_108_1(%rip), %ymm8, %ymm5
vpand mask_109_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_110_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_111_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $62, %ymm7, %ymm5
vpsllq $2, %ymm7, %ymm4
vpermq $147, %ymm5, %ymm6
vpxor %ymm4, %ymm6, %ymm6
vpshufb mask_112_1(%rip), %ymm6, %ymm5
vpand mask_113_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_114_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_115_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm6, %ymm8
vpshufb mask_116_1(%rip), %ymm8, %ymm5
vpand mask_117_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_118_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_119_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsllq $1, %ymm6, %ymm7
vpshufb mask_120_1(%rip), %ymm7, %ymm5
vpand mask_121_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_122_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_123_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm8
vpshufb mask_124_1(%rip), %ymm8, %ymm5
vpand mask_125_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_126_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_127_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vmovdqa 64(%rsi), %ymm0
vpshufb mask_128_1(%rip), %ymm0, %ymm5
vpand mask_129_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_130_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_131_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm0, %ymm8
vpshufb mask_132_1(%rip), %ymm8, %ymm5
vpand mask_133_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_134_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_135_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $63, %ymm0, %ymm5
vpsllq $1, %ymm0, %ymm4
vpermq $147, %ymm5, %ymm6
vpxor %ymm4, %ymm6, %ymm6
vpshufb mask_136_1(%rip), %ymm6, %ymm5
vpand mask_137_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_138_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_139_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm6, %ymm8
vpshufb mask_140_1(%rip), %ymm8, %ymm5
vpand mask_141_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_142_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_143_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $63, %ymm6, %ymm5
vpsllq $1, %ymm6, %ymm4
vpermq $147, %ymm5, %ymm7
vpxor %ymm4, %ymm7, %ymm7
vpshufb mask_144_1(%rip), %ymm7, %ymm5
vpand mask_145_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_146_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_147_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm8
vpshufb mask_148_1(%rip), %ymm8, %ymm5
vpand mask_149_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_150_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_151_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $63, %ymm7, %ymm5
vpsllq $1, %ymm7, %ymm4
vpermq $147, %ymm5, %ymm6
vpxor %ymm4, %ymm6, %ymm6
vpshufb mask_152_1(%rip), %ymm6, %ymm5
vpand mask_153_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_154_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_155_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm6, %ymm8
vpshufb mask_156_1(%rip), %ymm8, %ymm5
vpand mask_157_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_158_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_159_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $63, %ymm6, %ymm5
vpsllq $1, %ymm6, %ymm4
vpermq $147, %ymm5, %ymm7
vpxor %ymm4, %ymm7, %ymm7
vpshufb mask_160_1(%rip), %ymm7, %ymm5
vpand mask_161_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_162_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_163_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm8
vpshufb mask_164_1(%rip), %ymm8, %ymm5
vpand mask_165_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_166_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_167_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $63, %ymm7, %ymm5
vpsllq $1, %ymm7, %ymm4
vpermq $147, %ymm5, %ymm6
vpxor %ymm4, %ymm6, %ymm6
vpshufb mask_168_1(%rip), %ymm6, %ymm5
vpand mask_169_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_170_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_171_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm6, %ymm8
vpshufb mask_172_1(%rip), %ymm8, %ymm5
vpand mask_173_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_174_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_175_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $63, %ymm6, %ymm5
vpsllq $1, %ymm6, %ymm4
vpermq $147, %ymm5, %ymm7
vpxor %ymm4, %ymm7, %ymm7
vpshufb mask_176_1(%rip), %ymm7, %ymm5
vpand mask_177_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_178_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_179_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm8
vpshufb mask_180_1(%rip), %ymm8, %ymm5
vpand mask_181_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_182_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_183_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpsrlq $63, %ymm7, %ymm5
vpsllq $1, %ymm7, %ymm4
vpermq $147, %ymm5, %ymm6
vpxor %ymm4, %ymm6, %ymm6
vpshufb mask_184_1(%rip), %ymm6, %ymm5
vpand mask_185_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_186_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_187_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vpermq $78, %ymm6, %ymm8
vpshufb mask_188_1(%rip), %ymm8, %ymm5
vpand mask_189_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm1, %ymm1
vpand mask_190_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm2, %ymm2
vpand mask_191_1(%rip), %ymm5, %ymm4
vpxor %ymm4, %ymm3, %ymm3
vmovdqa %ymm1, 0(%rdi)
vmovdqa %ymm2, 32(%rdi)
vmovdqa %ymm3, 64(%rdi)
ret
