#ifndef PQCLEAN_NTRULPR1013_CLEAN_CRYPTO_ENCODE_1013X2393_H
#define PQCLEAN_NTRULPR1013_CLEAN_CRYPTO_ENCODE_1013X2393_H

#include <stdint.h>
#define PQCLEAN_NTRULPR1013_CLEAN_crypto_encode_1013x2393_STRBYTES 1423
#define PQCLEAN_NTRULPR1013_CLEAN_crypto_encode_1013x2393_ITEMS 1013
#define PQCLEAN_NTRULPR1013_CLEAN_crypto_encode_1013x2393_ITEMBYTES 2

void PQCLEAN_NTRULPR1013_CLEAN_crypto_encode_1013x2393(unsigned char *out, const void *v);
#endif
