#ifndef PQCLEAN_SNTRUP953_AVX2_CRYPTO_CORE_WFORCESNTRUP953_H
#define PQCLEAN_SNTRUP953_AVX2_CRYPTO_CORE_WFORCESNTRUP953_H

#include <stdint.h>
#define PQCLEAN_SNTRUP953_AVX2_crypto_core_wforcesntrup953_OUTPUTBYTES 953
#define PQCLEAN_SNTRUP953_AVX2_crypto_core_wforcesntrup953_INPUTBYTES 953
#define PQCLEAN_SNTRUP953_AVX2_crypto_core_wforcesntrup953_KEYBYTES 0
#define PQCLEAN_SNTRUP953_AVX2_crypto_core_wforcesntrup953_CONSTBYTES 0

int PQCLEAN_SNTRUP953_AVX2_crypto_core_wforcesntrup953(unsigned char *out, const unsigned char *in);
#endif
