#ifndef PQCLEAN_NTRULPR1013_AVX2_CRYPTO_VERIFY_1583_H
#define PQCLEAN_NTRULPR1013_AVX2_CRYPTO_VERIFY_1583_H

#include <stdint.h>
#define PQCLEAN_NTRULPR1013_AVX2_crypto_verify_1583_BYTES 1583

int PQCLEAN_NTRULPR1013_AVX2_crypto_verify_1583(const unsigned char *x, const unsigned char *y);
#endif
