#ifndef PQCLEAN_MCELIECE8192128F_VEC_TRANSPOSE_H
#define PQCLEAN_MCELIECE8192128F_VEC_TRANSPOSE_H
/*
  This file is for matrix transposition
*/


#include <stdint.h>


void PQCLEAN_MCELIECE8192128F_VEC_transpose_64x64(uint64_t *out, const uint64_t *in);

#endif

