#ifndef PQCLEAN_NTRULPR653_AVX2_CRYPTO_DECODE_653X1541_H
#define PQCLEAN_NTRULPR653_AVX2_CRYPTO_DECODE_653X1541_H

#include <stdint.h>
#define PQCLEAN_NTRULPR653_AVX2_crypto_decode_653x1541_STRBYTES 865
#define PQCLEAN_NTRULPR653_AVX2_crypto_decode_653x1541_ITEMS 653
#define PQCLEAN_NTRULPR653_AVX2_crypto_decode_653x1541_ITEMBYTES 2

void PQCLEAN_NTRULPR653_AVX2_crypto_decode_653x1541(void *v, const unsigned char *s);
#endif
