#ifndef PQCLEAN_MCELIECE8192128_VEC_FFT_TR_H
#define PQCLEAN_MCELIECE8192128_VEC_FFT_TR_H
/*
  This file is for transpose of the Gao-Mateer FFT
*/


#include "params.h"
#include "vec.h"

void PQCLEAN_MCELIECE8192128_VEC_fft_tr(vec out[][GFBITS], vec in[][ GFBITS ]);

#endif

