#ifndef PQCLEAN_SNTRUP953_AVX2_CRYPTO_ENCODE_953X2115ROUND_H
#define PQCLEAN_SNTRUP953_AVX2_CRYPTO_ENCODE_953X2115ROUND_H

#include <stdint.h>
#define PQCLEAN_SNTRUP953_AVX2_crypto_encode_953x2115round_STRBYTES 1317
#define PQCLEAN_SNTRUP953_AVX2_crypto_encode_953x2115round_ITEMS 953
#define PQCLEAN_SNTRUP953_AVX2_crypto_encode_953x2115round_ITEMBYTES 2

void PQCLEAN_SNTRUP953_AVX2_crypto_encode_953x2115round(unsigned char *out, const void *v);
#endif
