#ifndef PQCLEAN_SNTRUP857_CLEAN_CRYPTO_VERIFY_1184_H
#define PQCLEAN_SNTRUP857_CLEAN_CRYPTO_VERIFY_1184_H

#include <stdint.h>
#define PQCLEAN_SNTRUP857_CLEAN_crypto_verify_1184_BYTES 1184

int PQCLEAN_SNTRUP857_CLEAN_crypto_verify_1184(const unsigned char *x, const unsigned char *y);
#endif
