.data
.p2align 5
mask_0_1:
.byte 0
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 8
.byte 5
.byte 2
.byte 2
.byte 2
.byte 255
.byte 255

mask_1_1:
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8002
.word 0x2040
.word 0x0
.word 0x0

mask_2_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x0

mask_3_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0

mask_4_1:
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_5_1:
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 5
.byte 5
.byte 255
.byte 255
.byte 255

mask_6_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0

mask_7_1:
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2040
.word 0x0
.word 0x0

mask_8_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x0

mask_9_1:
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 11
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255

mask_10_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0

mask_11_1:
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2040
.word 0x0
.word 0x0

mask_12_1:
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_13_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0

mask_14_1:
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_15_1:
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_16_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0

mask_17_1:
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_18_1:
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_19_1:
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_20_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 6

mask_21_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x810
.word 0x204

mask_22_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9

mask_23_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x204

mask_24_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12

mask_25_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x204

mask_26_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_27_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_28_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_29_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_30_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_31_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 7
.byte 4
.byte 1
.byte 14
.byte 11
.byte 8
.byte 5
.byte 2
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_32_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8002
.word 0x2040
.word 0x810
.word 0x204
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_33_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_34_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 7
.byte 4
.byte 255
.byte 14
.byte 11
.byte 8
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_35_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_36_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2040
.word 0x800
.word 0x204
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_37_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 10
.byte 10
.byte 7
.byte 255
.byte 255
.byte 14
.byte 11
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_38_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_39_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2040
.word 0x0
.word 0x204
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_40_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_41_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_42_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_43_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_44_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_45_1:
.byte 0
.byte 0
.byte 255
.byte 255
.byte 13
.byte 10
.byte 7
.byte 4
.byte 1
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_46_1:
.word 0x0
.word 0x0
.word 0x810
.word 0x204
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_47_1:
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_48_1:
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_49_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 10
.byte 7
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_50_1:
.word 0x0
.word 0x0
.word 0x800
.word 0x204
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_51_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 10
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_52_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_53_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x204
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_54_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_55_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_56_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_57_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_58_1:
.byte 13
.byte 6
.byte 3
.byte 0
.byte 0
.byte 0
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_59_1:
.word 0x8002
.word 0x2040
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_60_1:
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_61_1:
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_62_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_63_1:
.byte 255
.byte 10
.byte 6
.byte 3
.byte 3
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_64_1:
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_65_1:
.word 0x0
.word 0x2040
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_66_1:
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_67_1:
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_68_1:
.byte 255
.byte 9
.byte 9
.byte 6
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_69_1:
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_70_1:
.word 0x0
.word 0x2040
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_71_1:
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_72_1:
.byte 255
.byte 13
.byte 12
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_73_1:
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_74_1:
.word 0x0
.word 0x2040
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_75_1:
.byte 255
.byte 12
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_76_1:
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_77_1:
.byte 255
.byte 15
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_78_1:
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_79_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 8
.byte 5
.byte 2
.byte 2
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_80_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8002
.word 0x2040
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_81_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x0

mask_82_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0

mask_83_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 5
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_84_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_85_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2040
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_86_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x0

mask_87_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 11
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_88_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_89_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2040
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_90_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_91_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_92_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_93_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_94_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 6
.byte 3
.byte 2
.byte 255
.byte 255

mask_95_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x810
.word 0x204
.word 0x1
.word 0x0

mask_96_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0

mask_97_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 2
.byte 255
.byte 255
.byte 255

mask_98_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x204
.word 0x80
.word 0x0

mask_99_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 6
.byte 255
.byte 255
.byte 255

mask_100_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0

mask_101_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x204
.word 0x0
.word 0x0

mask_102_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255

mask_103_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0

mask_104_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 9
.byte 255
.byte 255
.byte 255

mask_105_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0

mask_106_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 8
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_107_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x810
.word 0x204
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_108_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_109_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x204
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_110_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_111_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x204
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_112_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 7
.byte 4
.byte 1
.byte 1
.byte 1
.byte 255
.byte 255
.byte 2
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_113_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8002
.word 0x2040
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_114_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_115_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_116_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 7
.byte 4
.byte 4
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_117_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_118_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2040
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_119_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_120_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 10
.byte 10
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_121_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_122_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2040
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_123_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_124_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_125_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_126_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_127_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_128_1:
.byte 13
.byte 10
.byte 7
.byte 4
.byte 1
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 9
.byte 6
.byte 3

mask_129_1:
.word 0x810
.word 0x204
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x2040

mask_130_1:
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_131_1:
.byte 255
.byte 13
.byte 10
.byte 7
.byte 0
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 9
.byte 6

mask_132_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0

mask_133_1:
.word 0x800
.word 0x204
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2040

mask_134_1:
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_135_1:
.byte 255
.byte 255
.byte 13
.byte 10
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 12
.byte 9

mask_136_1:
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0

mask_137_1:
.word 0x0
.word 0x204
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2040

mask_138_1:
.byte 255
.byte 255
.byte 255
.byte 13
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 255
.byte 255

mask_139_1:
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0

mask_140_1:
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_141_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_142_1:
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_143_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_144_1:
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_145_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 10
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_146_1:
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_147_1:
.byte 0
.byte 0
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 0
.byte 255
.byte 255

mask_148_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x0

mask_149_1:
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0

mask_150_1:
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_151_1:
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_152_1:
.byte 3
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_153_1:
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_154_1:
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_155_1:
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_156_1:
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_157_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 8
.byte 5
.byte 2
.byte 2
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_158_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8002
.word 0x2040
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_159_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_160_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_161_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 8
.byte 5
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_162_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_163_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2040
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_164_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_165_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 11
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_166_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_167_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2040
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_168_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_169_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_170_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_171_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_172_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 6
.byte 3
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_173_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x810
.word 0x204
.word 0x1
.word 0x0
.word 0x0
.word 0x0

mask_174_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0

mask_175_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_176_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x204
.word 0x80
.word 0x0
.word 0x0
.word 0x0

mask_177_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_178_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0

mask_179_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x204
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_180_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_181_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0

mask_182_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_183_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0

mask_184_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 8
.byte 5
.byte 2
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_185_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x810
.word 0x204
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_186_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_187_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 8
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_188_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x204
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_189_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_190_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_191_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x204
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_192_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_193_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_194_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_195_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_196_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 7
.byte 4
.byte 1
.byte 1
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_197_1:
.word 0x0
.word 0x0
.word 0x8002
.word 0x2040
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_198_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_199_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_200_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 7
.byte 4
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_201_1:
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_202_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x2040
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_203_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_204_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 10
.byte 10
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_205_1:
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_206_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x2040
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_207_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_208_1:
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_209_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_210_1:
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_211_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 8
.byte 1
.byte 1
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_212_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x204
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_213_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_214_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_215_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 5
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_216_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_217_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x204
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_218_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_219_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_220_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_221_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_222_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_223_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_224_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_225_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_226_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_227_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_228_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 8
.byte 5
.byte 2
.byte 2
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_229_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x4000
.word 0x1020
.word 0x408
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_230_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0

mask_231_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0

mask_232_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 8
.byte 5
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_233_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1020
.word 0x408
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_234_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0

mask_235_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_236_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x408
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_237_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 10
.byte 7
.byte 4
.byte 1
.byte 1
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_238_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x1020
.word 0x408
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_239_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_240_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_241_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 10
.byte 7
.byte 4
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_242_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1020
.word 0x408
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_243_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_244_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 10
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_245_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x408
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_246_1:
.byte 255
.byte 255
.byte 255
.byte 13
.byte 10
.byte 7
.byte 0
.byte 0
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_247_1:
.word 0x0
.word 0x800
.word 0x204
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_248_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_249_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_250_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 10
.byte 4
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_251_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_252_1:
.word 0x0
.word 0x0
.word 0x204
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_253_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_254_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_255_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_256_1:
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_257_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_258_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_259_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_260_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_261_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 10
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_262_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_263_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_264_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_265_1:
.byte 3
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 2
.byte 2
.byte 2
.byte 255
.byte 255
.byte 255

mask_266_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x204
.word 0x80
.word 0x0
.word 0x0

mask_267_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0

mask_268_1:
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0

mask_269_1:
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_270_1:
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 6
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255

mask_271_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0

mask_272_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x204
.word 0x0
.word 0x0
.word 0x0

mask_273_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0

mask_274_1:
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_275_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_276_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0

mask_277_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0

mask_278_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_279_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0

mask_280_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_281_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0

mask_282_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_283_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0

mask_284_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 6
.byte 3

mask_285_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x1020
.word 0x408

mask_286_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 6

mask_287_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1020
.word 0x408

mask_288_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9

mask_289_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x408

mask_290_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_291_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_292_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_293_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 8
.byte 1
.byte 1
.byte 11
.byte 8
.byte 5
.byte 2
.byte 2
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_294_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x204
.word 0x80
.word 0x1020
.word 0x408
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_295_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_296_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_297_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 5
.byte 4
.byte 14
.byte 11
.byte 8
.byte 5
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_298_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_299_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x204
.word 0x0
.word 0x1020
.word 0x408
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_300_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_301_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 4
.byte 255
.byte 255
.byte 14
.byte 11
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_302_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_303_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x1000
.word 0x408
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_304_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_305_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_306_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_307_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_308_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_309_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_310_1:
.byte 0
.byte 0
.byte 255
.byte 13
.byte 10
.byte 7
.byte 4
.byte 1
.byte 1
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_311_1:
.word 0x0
.word 0x4000
.word 0x1020
.word 0x408
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_312_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_313_1:
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_314_1:
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_315_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 10
.byte 7
.byte 4
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_316_1:
.word 0x0
.word 0x0
.word 0x1020
.word 0x408
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_317_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_318_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 10
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_319_1:
.word 0x0
.word 0x0
.word 0x1000
.word 0x408
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_320_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_321_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_322_1:
.byte 10
.byte 7
.byte 0
.byte 0
.byte 0
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0

mask_323_1:
.word 0x204
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800

mask_324_1:
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_325_1:
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_326_1:
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_327_1:
.byte 13
.byte 10
.byte 4
.byte 3
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_328_1:
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_329_1:
.word 0x204
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_330_1:
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_331_1:
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_332_1:
.byte 255
.byte 13
.byte 3
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_333_1:
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_334_1:
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_335_1:
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_336_1:
.byte 255
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_337_1:
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_338_1:
.byte 255
.byte 255
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_339_1:
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_340_1:
.byte 255
.byte 255
.byte 10
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_341_1:
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_342_1:
.byte 255
.byte 255
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_343_1:
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_344_1:
.byte 255
.byte 255
.byte 13
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_345_1:
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_346_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 2
.byte 2
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_347_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x204
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_348_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_349_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0

mask_350_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 6
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_351_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_352_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x204
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_353_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_354_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_355_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_356_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_357_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_358_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_359_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_360_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_361_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_362_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_363_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 6
.byte 3
.byte 3
.byte 3
.byte 255
.byte 255

mask_364_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x1020
.word 0x408
.word 0x0
.word 0x0

mask_365_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x0

mask_366_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0

mask_367_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 6
.byte 6
.byte 255
.byte 255
.byte 255

mask_368_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1020
.word 0x408
.word 0x0
.word 0x0

mask_369_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2
.word 0x0

mask_370_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255

mask_371_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x408
.word 0x0
.word 0x0

mask_372_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 8
.byte 5
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_373_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x1020
.word 0x408
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_374_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 8
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_375_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1020
.word 0x408
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_376_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_377_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x408
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_378_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 8
.byte 1
.byte 1
.byte 1
.byte 255
.byte 255
.byte 255
.byte 2
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_379_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x204
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_380_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_381_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_382_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 5
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_383_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_384_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x204
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_385_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_386_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_387_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_388_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_389_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_390_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_391_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_392_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_393_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_394_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_395_1:
.byte 10
.byte 7
.byte 4
.byte 1
.byte 1
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 10
.byte 3
.byte 0

mask_396_1:
.word 0x1020
.word 0x408
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x204
.word 0x4080

mask_397_1:
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_398_1:
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_399_1:
.byte 13
.byte 10
.byte 7
.byte 4
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 7
.byte 3

mask_400_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1

mask_401_1:
.word 0x1020
.word 0x408
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x4000

mask_402_1:
.word 0x0
.word 0x0
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_403_1:
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_404_1:
.byte 255
.byte 13
.byte 10
.byte 7
.byte 7
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 6
.byte 6

mask_405_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80

mask_406_1:
.word 0x1000
.word 0x408
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000

mask_407_1:
.word 0x0
.word 0x0
.word 0x102
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_408_1:
.byte 255
.byte 255
.byte 13
.byte 10
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 10
.byte 255

mask_409_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1

mask_410_1:
.word 0x0
.word 0x408
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_411_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 9
.byte 255

mask_412_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x80

mask_413_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 255

mask_414_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1

mask_415_1:
.byte 0
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 0
.byte 0
.byte 255
.byte 255

mask_416_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0

mask_417_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0

mask_418_1:
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x200
.word 0x0

mask_419_1:
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_420_1:
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_421_1:
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_422_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 10
.byte 7
.byte 4
.byte 1
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_423_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x2040
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_424_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_425_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 10
.byte 7
.byte 4
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_426_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_427_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2040
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_428_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_429_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 13
.byte 10
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_430_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_431_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2040
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_432_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 10
.byte 7
.byte 4
.byte 1
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_433_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x1020
.word 0x408
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_434_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_435_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_436_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 10
.byte 7
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_437_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x408
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_438_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_439_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 10
.byte 7
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_440_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x408
.word 0x102
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_441_1:
.byte 6
.byte 3
.byte 0
.byte 0
.byte 0
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 6
.byte 3
.byte 0

mask_442_1:
.word 0x2040
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1020
.word 0x408
.word 0x102

mask_443_1:
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_444_1:
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_445_1:
.word 0x0
.word 0x0
.word 0x200
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_446_1:
.byte 9
.byte 6
.byte 3
.byte 3
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 6
.byte 3

mask_447_1:
.word 0x2040
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x408
.word 0x102

mask_448_1:
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_449_1:
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_450_1:
.byte 12
.byte 9
.byte 6
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 2

mask_451_1:
.word 0x2040
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x408
.word 0x8002

mask_452_1:
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_453_1:
.byte 15
.byte 12
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 6

mask_454_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100

mask_455_1:
.word 0x2040
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_456_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12

mask_457_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000

mask_458_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15

mask_459_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000

mask_460_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 8
.byte 5
.byte 2
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_461_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x408
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_462_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_463_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 8
.byte 5
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_464_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x408
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_465_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_466_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 8
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_467_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x408
.word 0x102
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_468_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 255
.byte 255
.byte 255
.byte 11
.byte 8
.byte 5
.byte 2
.byte 2
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_469_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1020
.word 0x0
.word 0x8000
.word 0x2040
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_470_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_471_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0

mask_472_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 255
.byte 255
.byte 255
.byte 15
.byte 11
.byte 8
.byte 5
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_473_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_474_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x2040
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_475_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_476_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 14
.byte 11
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_477_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_478_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2040
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_479_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 10
.byte 7
.byte 4
.byte 1
.byte 1
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_480_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x2040
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_481_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_482_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_483_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 10
.byte 7
.byte 4
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_484_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_485_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2040
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_486_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_487_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 13
.byte 10
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_488_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_489_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2040
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_490_1:
.byte 255
.byte 255
.byte 13
.byte 10
.byte 7
.byte 4
.byte 1
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_491_1:
.word 0x0
.word 0x1020
.word 0x408
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_492_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_493_1:
.byte 255
.byte 255
.byte 255
.byte 13
.byte 10
.byte 7
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_494_1:
.word 0x0
.word 0x1000
.word 0x408
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_495_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_496_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 10
.byte 7
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_497_1:
.word 0x0
.word 0x0
.word 0x408
.word 0x102
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_498_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 10
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_499_1:
.word 0x0
.word 0x0
.word 0x400
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_500_1:
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 6
.byte 3
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255

mask_501_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1020
.word 0x408
.word 0x102
.word 0x0
.word 0x0

mask_502_1:
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_503_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 6
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255

mask_504_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x408
.word 0x102
.word 0x0
.word 0x0

mask_505_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255

mask_506_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x408
.word 0x8002
.word 0x0
.word 0x0

mask_507_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255

mask_508_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0

mask_509_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 9
.byte 6
.byte 3
.byte 3

mask_510_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x2040
.word 0x10

mask_511_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800

mask_512_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 6
.byte 6

mask_513_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x2040
.word 0x10

mask_514_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800

mask_515_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 255

mask_516_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2040
.word 0x10

mask_517_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 11
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_518_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_519_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_520_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_521_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_522_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_523_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 8
.byte 5
.byte 2
.byte 2
.byte 8
.byte 5
.byte 2
.byte 2
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_524_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1020
.word 0x408
.word 0x2
.word 0x2040
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_525_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_526_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_527_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 8
.byte 5
.byte 1
.byte 11
.byte 8
.byte 5
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_528_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x408
.word 0x2
.word 0x2040
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_529_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_530_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 14
.byte 11
.byte 8
.byte 5
.byte 14
.byte 11
.byte 8
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_531_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x408
.word 0x102
.word 0x2040
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_532_1:
.byte 0
.byte 255
.byte 255
.byte 10
.byte 7
.byte 4
.byte 1
.byte 1
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13

mask_533_1:
.word 0x0
.word 0x8000
.word 0x2040
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000

mask_534_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_535_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_536_1:
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_537_1:
.byte 255
.byte 255
.byte 255
.byte 14
.byte 10
.byte 7
.byte 4
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_538_1:
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_539_1:
.word 0x0
.word 0x0
.word 0x2040
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_540_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_541_1:
.byte 255
.byte 255
.byte 255
.byte 13
.byte 13
.byte 10
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_542_1:
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_543_1:
.word 0x0
.word 0x0
.word 0x2040
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_544_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 13
.byte 10
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_545_1:
.word 0x0
.word 0x0
.word 0x2000
.word 0x10
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_546_1:
.byte 7
.byte 4
.byte 1
.byte 1
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 0
.byte 0

mask_547_1:
.word 0x408
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20

mask_548_1:
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000

mask_549_1:
.word 0x0
.word 0x0
.word 0x40
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_550_1:
.byte 10
.byte 7
.byte 4
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_551_1:
.word 0x408
.word 0x2
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_552_1:
.word 0x0
.word 0x8000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_553_1:
.byte 13
.byte 10
.byte 7
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_554_1:
.word 0x408
.word 0x102
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_555_1:
.byte 255
.byte 13
.byte 10
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_556_1:
.word 0x400
.word 0x8002
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_557_1:
.byte 255
.byte 255
.byte 255
.byte 7
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_558_1:
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_559_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 6
.byte 3
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_560_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1020
.word 0x408
.word 0x102
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_561_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 6
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_562_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x408
.word 0x102
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_563_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_564_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x408
.word 0x8002
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_565_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_566_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x100
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_567_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 12
.byte 9
.byte 6
.byte 3
.byte 3
.byte 3
.byte 255
.byte 255
.byte 255

mask_568_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x2040
.word 0x10
.word 0x0
.word 0x0

mask_569_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0

mask_570_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4
.word 0x0

mask_571_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 6
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255

mask_572_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x8000
.word 0x2040
.word 0x10
.word 0x0
.word 0x0

mask_573_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x800
.word 0x0
.word 0x0

mask_574_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 15
.byte 12
.byte 9
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_575_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x2040
.word 0x10
.word 0x0
.word 0x0

mask_576_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 0
.byte 0
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_577_1:
.word 0x0
.word 0x0
.word 0x4080
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_578_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_579_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_580_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 3
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_581_1:
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_582_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_583_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 2
.byte 2
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255

mask_584_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4080
.word 0x0
.word 0x0
.word 0x0

mask_585_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0

mask_586_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x0

mask_587_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_588_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0

mask_589_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0

mask_590_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 1
.byte 1
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_591_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4080
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_592_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_593_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_594_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_595_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_596_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_597_1:
.byte 3
.byte 0
.byte 0
.byte 0
.byte 0
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_598_1:
.word 0x4080
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_599_1:
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_600_1:
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_601_1:
.word 0x0
.word 0x0
.word 0x8
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_602_1:
.byte 6
.byte 3
.byte 3
.byte 3
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_603_1:
.word 0x4080
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_604_1:
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_605_1:
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_606_1:
.byte 255
.byte 6
.byte 6
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_607_1:
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_608_1:
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_609_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 2
.byte 2
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_610_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4080
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_611_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_612_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_613_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_614_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_615_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_616_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 1
.byte 1
.byte 1
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_617_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4080
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_618_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_619_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_620_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 4
.byte 4
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_621_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_622_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_623_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 6
.byte 3
.byte 3
.byte 3

mask_624_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4080
.word 0x0

mask_625_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20

mask_626_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000

mask_627_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 6
.byte 6
.byte 255

mask_628_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0

mask_629_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20

mask_630_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 2
.byte 2
.byte 2
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_631_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4080
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_632_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_633_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x1000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_634_1:
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 5
.byte 5
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255
.byte 255

mask_635_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x4000
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

mask_636_1:
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x20
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0
.word 0x0

.text
.global PQCLEAN_NTRUHPS4096821_AVX2_square_204_821
.global _PQCLEAN_NTRUHPS4096821_AVX2_square_204_821
PQCLEAN_NTRUHPS4096821_AVX2_square_204_821:
_PQCLEAN_NTRUHPS4096821_AVX2_square_204_821:
vmovdqa 0(%rsi), %ymm0
vpshufb mask_0_1(%rip), %ymm0, %ymm6
vpand mask_1_1(%rip), %ymm6, %ymm1
vpand mask_2_1(%rip), %ymm6, %ymm2
vpand mask_3_1(%rip), %ymm6, %ymm3
vpand mask_4_1(%rip), %ymm6, %ymm4
vpshufb mask_5_1(%rip), %ymm0, %ymm6
vpand mask_6_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_7_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_8_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_9_1(%rip), %ymm0, %ymm6
vpand mask_10_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_11_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_12_1(%rip), %ymm0, %ymm6
vpand mask_13_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_14_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_15_1(%rip), %ymm0, %ymm6
vpand mask_16_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_17_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_18_1(%rip), %ymm0, %ymm6
vpand mask_19_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpermq $78, %ymm0, %ymm9
vpshufb mask_20_1(%rip), %ymm9, %ymm6
vpand mask_21_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpshufb mask_22_1(%rip), %ymm9, %ymm6
vpand mask_23_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_24_1(%rip), %ymm9, %ymm6
vpand mask_25_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpsrlq $63, %ymm0, %ymm6
vpsllq $1, %ymm0, %ymm5
vpermq $147, %ymm6, %ymm7
vpxor %ymm5, %ymm7, %ymm7
vpshufb mask_26_1(%rip), %ymm7, %ymm6
vpand mask_27_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_28_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_29_1(%rip), %ymm7, %ymm6
vpand mask_30_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm9
vpshufb mask_31_1(%rip), %ymm9, %ymm6
vpand mask_32_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_33_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_34_1(%rip), %ymm9, %ymm6
vpand mask_35_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_36_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_37_1(%rip), %ymm9, %ymm6
vpand mask_38_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_39_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_40_1(%rip), %ymm9, %ymm6
vpand mask_41_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_42_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_43_1(%rip), %ymm9, %ymm6
vpand mask_44_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpsrlq $63, %ymm7, %ymm6
vpsllq $1, %ymm7, %ymm5
vpermq $147, %ymm6, %ymm8
vpxor %ymm5, %ymm8, %ymm8
vpshufb mask_45_1(%rip), %ymm8, %ymm6
vpand mask_46_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_47_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_48_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_49_1(%rip), %ymm8, %ymm6
vpand mask_50_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_51_1(%rip), %ymm8, %ymm6
vpand mask_52_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_53_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_54_1(%rip), %ymm8, %ymm6
vpand mask_55_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_56_1(%rip), %ymm8, %ymm6
vpand mask_57_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpermq $78, %ymm8, %ymm9
vpshufb mask_58_1(%rip), %ymm9, %ymm6
vpand mask_59_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_60_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_61_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_62_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_63_1(%rip), %ymm9, %ymm6
vpand mask_64_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_65_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_66_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_67_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_68_1(%rip), %ymm9, %ymm6
vpand mask_69_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_70_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_71_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_72_1(%rip), %ymm9, %ymm6
vpand mask_73_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_74_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_75_1(%rip), %ymm9, %ymm6
vpand mask_76_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_77_1(%rip), %ymm9, %ymm6
vpand mask_78_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpsllq $1, %ymm8, %ymm7
vpshufb mask_79_1(%rip), %ymm7, %ymm6
vpand mask_80_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_81_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_82_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_83_1(%rip), %ymm7, %ymm6
vpand mask_84_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_85_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_86_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_87_1(%rip), %ymm7, %ymm6
vpand mask_88_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_89_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_90_1(%rip), %ymm7, %ymm6
vpand mask_91_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_92_1(%rip), %ymm7, %ymm6
vpand mask_93_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm9
vpshufb mask_94_1(%rip), %ymm9, %ymm6
vpand mask_95_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_96_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_97_1(%rip), %ymm9, %ymm6
vpand mask_98_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_99_1(%rip), %ymm9, %ymm6
vpand mask_100_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_101_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_102_1(%rip), %ymm9, %ymm6
vpand mask_103_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_104_1(%rip), %ymm9, %ymm6
vpand mask_105_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpsrlq $62, %ymm8, %ymm6
vpsllq $2, %ymm8, %ymm5
vpermq $147, %ymm6, %ymm7
vpxor %ymm5, %ymm7, %ymm7
vpshufb mask_106_1(%rip), %ymm7, %ymm6
vpand mask_107_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpshufb mask_108_1(%rip), %ymm7, %ymm6
vpand mask_109_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_110_1(%rip), %ymm7, %ymm6
vpand mask_111_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm9
vpshufb mask_112_1(%rip), %ymm9, %ymm6
vpand mask_113_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_114_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_115_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_116_1(%rip), %ymm9, %ymm6
vpand mask_117_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_118_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_119_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_120_1(%rip), %ymm9, %ymm6
vpand mask_121_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_122_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_123_1(%rip), %ymm9, %ymm6
vpand mask_124_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_125_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_126_1(%rip), %ymm9, %ymm6
vpand mask_127_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpsrlq $63, %ymm7, %ymm6
vpsllq $1, %ymm7, %ymm5
vpermq $147, %ymm6, %ymm8
vpxor %ymm5, %ymm8, %ymm8
vpshufb mask_128_1(%rip), %ymm8, %ymm6
vpand mask_129_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_130_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_131_1(%rip), %ymm8, %ymm6
vpand mask_132_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_133_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_134_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_135_1(%rip), %ymm8, %ymm6
vpand mask_136_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_137_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_138_1(%rip), %ymm8, %ymm6
vpand mask_139_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_140_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_141_1(%rip), %ymm8, %ymm6
vpand mask_142_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_143_1(%rip), %ymm8, %ymm6
vpand mask_144_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_145_1(%rip), %ymm8, %ymm6
vpand mask_146_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpermq $78, %ymm8, %ymm9
vpshufb mask_147_1(%rip), %ymm9, %ymm6
vpand mask_148_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_149_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_150_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_151_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_152_1(%rip), %ymm9, %ymm6
vpand mask_153_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_154_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_155_1(%rip), %ymm9, %ymm6
vpand mask_156_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpsllq $1, %ymm8, %ymm7
vpshufb mask_157_1(%rip), %ymm7, %ymm6
vpand mask_158_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_159_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_160_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_161_1(%rip), %ymm7, %ymm6
vpand mask_162_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_163_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_164_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_165_1(%rip), %ymm7, %ymm6
vpand mask_166_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_167_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_168_1(%rip), %ymm7, %ymm6
vpand mask_169_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_170_1(%rip), %ymm7, %ymm6
vpand mask_171_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm9
vpshufb mask_172_1(%rip), %ymm9, %ymm6
vpand mask_173_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_174_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_175_1(%rip), %ymm9, %ymm6
vpand mask_176_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_177_1(%rip), %ymm9, %ymm6
vpand mask_178_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_179_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_180_1(%rip), %ymm9, %ymm6
vpand mask_181_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_182_1(%rip), %ymm9, %ymm6
vpand mask_183_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpsrlq $62, %ymm8, %ymm6
vpsllq $2, %ymm8, %ymm5
vpermq $147, %ymm6, %ymm7
vpxor %ymm5, %ymm7, %ymm7
vpshufb mask_184_1(%rip), %ymm7, %ymm6
vpand mask_185_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_186_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_187_1(%rip), %ymm7, %ymm6
vpand mask_188_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_189_1(%rip), %ymm7, %ymm6
vpand mask_190_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_191_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_192_1(%rip), %ymm7, %ymm6
vpand mask_193_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_194_1(%rip), %ymm7, %ymm6
vpand mask_195_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm9
vpshufb mask_196_1(%rip), %ymm9, %ymm6
vpand mask_197_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_198_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_199_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_200_1(%rip), %ymm9, %ymm6
vpand mask_201_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_202_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_203_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_204_1(%rip), %ymm9, %ymm6
vpand mask_205_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_206_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_207_1(%rip), %ymm9, %ymm6
vpand mask_208_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_209_1(%rip), %ymm9, %ymm6
vpand mask_210_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vmovdqa 32(%rsi), %ymm0
vpshufb mask_211_1(%rip), %ymm0, %ymm6
vpand mask_212_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_213_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_214_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_215_1(%rip), %ymm0, %ymm6
vpand mask_216_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_217_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_218_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_219_1(%rip), %ymm0, %ymm6
vpand mask_220_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_221_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_222_1(%rip), %ymm0, %ymm6
vpand mask_223_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_224_1(%rip), %ymm0, %ymm6
vpand mask_225_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_226_1(%rip), %ymm0, %ymm6
vpand mask_227_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpermq $78, %ymm0, %ymm9
vpshufb mask_228_1(%rip), %ymm9, %ymm6
vpand mask_229_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_230_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_231_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_232_1(%rip), %ymm9, %ymm6
vpand mask_233_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_234_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_235_1(%rip), %ymm9, %ymm6
vpand mask_236_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpsllq $1, %ymm0, %ymm7
vpshufb mask_237_1(%rip), %ymm7, %ymm6
vpand mask_238_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_239_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_240_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_241_1(%rip), %ymm7, %ymm6
vpand mask_242_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_243_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_244_1(%rip), %ymm7, %ymm6
vpand mask_245_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm9
vpshufb mask_246_1(%rip), %ymm9, %ymm6
vpand mask_247_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_248_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_249_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_250_1(%rip), %ymm9, %ymm6
vpand mask_251_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_252_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_253_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_254_1(%rip), %ymm9, %ymm6
vpand mask_255_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_256_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_257_1(%rip), %ymm9, %ymm6
vpand mask_258_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_259_1(%rip), %ymm9, %ymm6
vpand mask_260_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_261_1(%rip), %ymm9, %ymm6
vpand mask_262_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_263_1(%rip), %ymm9, %ymm6
vpand mask_264_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpsllq $2, %ymm0, %ymm7
vpshufb mask_265_1(%rip), %ymm7, %ymm6
vpand mask_266_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_267_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_268_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_269_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_270_1(%rip), %ymm7, %ymm6
vpand mask_271_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_272_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_273_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_274_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_275_1(%rip), %ymm7, %ymm6
vpand mask_276_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_277_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_278_1(%rip), %ymm7, %ymm6
vpand mask_279_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_280_1(%rip), %ymm7, %ymm6
vpand mask_281_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_282_1(%rip), %ymm7, %ymm6
vpand mask_283_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm9
vpshufb mask_284_1(%rip), %ymm9, %ymm6
vpand mask_285_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpshufb mask_286_1(%rip), %ymm9, %ymm6
vpand mask_287_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_288_1(%rip), %ymm9, %ymm6
vpand mask_289_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpsrlq $61, %ymm0, %ymm6
vpsllq $3, %ymm0, %ymm5
vpermq $147, %ymm6, %ymm7
vpxor %ymm5, %ymm7, %ymm7
vpshufb mask_290_1(%rip), %ymm7, %ymm6
vpand mask_291_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_292_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm9
vpshufb mask_293_1(%rip), %ymm9, %ymm6
vpand mask_294_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_295_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_296_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_297_1(%rip), %ymm9, %ymm6
vpand mask_298_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_299_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_300_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_301_1(%rip), %ymm9, %ymm6
vpand mask_302_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_303_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_304_1(%rip), %ymm9, %ymm6
vpand mask_305_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_306_1(%rip), %ymm9, %ymm6
vpand mask_307_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_308_1(%rip), %ymm9, %ymm6
vpand mask_309_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpsllq $1, %ymm7, %ymm8
vpshufb mask_310_1(%rip), %ymm8, %ymm6
vpand mask_311_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_312_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_313_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_314_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_315_1(%rip), %ymm8, %ymm6
vpand mask_316_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_317_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_318_1(%rip), %ymm8, %ymm6
vpand mask_319_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_320_1(%rip), %ymm8, %ymm6
vpand mask_321_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpermq $78, %ymm8, %ymm9
vpshufb mask_322_1(%rip), %ymm9, %ymm6
vpand mask_323_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_324_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_325_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_326_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_327_1(%rip), %ymm9, %ymm6
vpand mask_328_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_329_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_330_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_331_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_332_1(%rip), %ymm9, %ymm6
vpand mask_333_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_334_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_335_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_336_1(%rip), %ymm9, %ymm6
vpand mask_337_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_338_1(%rip), %ymm9, %ymm6
vpand mask_339_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_340_1(%rip), %ymm9, %ymm6
vpand mask_341_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_342_1(%rip), %ymm9, %ymm6
vpand mask_343_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_344_1(%rip), %ymm9, %ymm6
vpand mask_345_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpsllq $2, %ymm7, %ymm8
vpshufb mask_346_1(%rip), %ymm8, %ymm6
vpand mask_347_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_348_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_349_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_350_1(%rip), %ymm8, %ymm6
vpand mask_351_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_352_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_353_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_354_1(%rip), %ymm8, %ymm6
vpand mask_355_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_356_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_357_1(%rip), %ymm8, %ymm6
vpand mask_358_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_359_1(%rip), %ymm8, %ymm6
vpand mask_360_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_361_1(%rip), %ymm8, %ymm6
vpand mask_362_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpermq $78, %ymm8, %ymm9
vpshufb mask_363_1(%rip), %ymm9, %ymm6
vpand mask_364_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_365_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_366_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_367_1(%rip), %ymm9, %ymm6
vpand mask_368_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_369_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_370_1(%rip), %ymm9, %ymm6
vpand mask_371_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpsrlq $61, %ymm7, %ymm6
vpsllq $3, %ymm7, %ymm5
vpermq $147, %ymm6, %ymm8
vpxor %ymm5, %ymm8, %ymm8
vpshufb mask_372_1(%rip), %ymm8, %ymm6
vpand mask_373_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpshufb mask_374_1(%rip), %ymm8, %ymm6
vpand mask_375_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_376_1(%rip), %ymm8, %ymm6
vpand mask_377_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpermq $78, %ymm8, %ymm9
vpshufb mask_378_1(%rip), %ymm9, %ymm6
vpand mask_379_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_380_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_381_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_382_1(%rip), %ymm9, %ymm6
vpand mask_383_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_384_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_385_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_386_1(%rip), %ymm9, %ymm6
vpand mask_387_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_388_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_389_1(%rip), %ymm9, %ymm6
vpand mask_390_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_391_1(%rip), %ymm9, %ymm6
vpand mask_392_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_393_1(%rip), %ymm9, %ymm6
vpand mask_394_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpsllq $1, %ymm8, %ymm7
vpshufb mask_395_1(%rip), %ymm7, %ymm6
vpand mask_396_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_397_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_398_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_399_1(%rip), %ymm7, %ymm6
vpand mask_400_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_401_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_402_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_403_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_404_1(%rip), %ymm7, %ymm6
vpand mask_405_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_406_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_407_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_408_1(%rip), %ymm7, %ymm6
vpand mask_409_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_410_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_411_1(%rip), %ymm7, %ymm6
vpand mask_412_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_413_1(%rip), %ymm7, %ymm6
vpand mask_414_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm9
vpshufb mask_415_1(%rip), %ymm9, %ymm6
vpand mask_416_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_417_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_418_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_419_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_420_1(%rip), %ymm9, %ymm6
vpand mask_421_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vmovdqa 64(%rsi), %ymm0
vpshufb mask_422_1(%rip), %ymm0, %ymm6
vpand mask_423_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_424_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_425_1(%rip), %ymm0, %ymm6
vpand mask_426_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_427_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_428_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_429_1(%rip), %ymm0, %ymm6
vpand mask_430_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_431_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpermq $78, %ymm0, %ymm9
vpshufb mask_432_1(%rip), %ymm9, %ymm6
vpand mask_433_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_434_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_435_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_436_1(%rip), %ymm9, %ymm6
vpand mask_437_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_438_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_439_1(%rip), %ymm9, %ymm6
vpand mask_440_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpsrlq $63, %ymm0, %ymm6
vpsllq $1, %ymm0, %ymm5
vpermq $147, %ymm6, %ymm7
vpxor %ymm5, %ymm7, %ymm7
vpshufb mask_441_1(%rip), %ymm7, %ymm6
vpand mask_442_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_443_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_444_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_445_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_446_1(%rip), %ymm7, %ymm6
vpand mask_447_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_448_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_449_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_450_1(%rip), %ymm7, %ymm6
vpand mask_451_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_452_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_453_1(%rip), %ymm7, %ymm6
vpand mask_454_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_455_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpermq $78, %ymm7, %ymm9
vpshufb mask_456_1(%rip), %ymm9, %ymm6
vpand mask_457_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpshufb mask_458_1(%rip), %ymm9, %ymm6
vpand mask_459_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpsllq $1, %ymm7, %ymm8
vpshufb mask_460_1(%rip), %ymm8, %ymm6
vpand mask_461_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_462_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_463_1(%rip), %ymm8, %ymm6
vpand mask_464_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_465_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_466_1(%rip), %ymm8, %ymm6
vpand mask_467_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpermq $78, %ymm8, %ymm9
vpshufb mask_468_1(%rip), %ymm9, %ymm6
vpand mask_469_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_470_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_471_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_472_1(%rip), %ymm9, %ymm6
vpand mask_473_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_474_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_475_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_476_1(%rip), %ymm9, %ymm6
vpand mask_477_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_478_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpsllq $2, %ymm7, %ymm8
vpshufb mask_479_1(%rip), %ymm8, %ymm6
vpand mask_480_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_481_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_482_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_483_1(%rip), %ymm8, %ymm6
vpand mask_484_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_485_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_486_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_487_1(%rip), %ymm8, %ymm6
vpand mask_488_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_489_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpermq $78, %ymm8, %ymm9
vpshufb mask_490_1(%rip), %ymm9, %ymm6
vpand mask_491_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_492_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_493_1(%rip), %ymm9, %ymm6
vpand mask_494_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_495_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_496_1(%rip), %ymm9, %ymm6
vpand mask_497_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_498_1(%rip), %ymm9, %ymm6
vpand mask_499_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpsrlq $61, %ymm7, %ymm6
vpsllq $3, %ymm7, %ymm5
vpermq $147, %ymm6, %ymm8
vpxor %ymm5, %ymm8, %ymm8
vpshufb mask_500_1(%rip), %ymm8, %ymm6
vpand mask_501_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_502_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_503_1(%rip), %ymm8, %ymm6
vpand mask_504_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_505_1(%rip), %ymm8, %ymm6
vpand mask_506_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_507_1(%rip), %ymm8, %ymm6
vpand mask_508_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpermq $78, %ymm8, %ymm9
vpshufb mask_509_1(%rip), %ymm9, %ymm6
vpand mask_510_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_511_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_512_1(%rip), %ymm9, %ymm6
vpand mask_513_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_514_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_515_1(%rip), %ymm9, %ymm6
vpand mask_516_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpsllq $1, %ymm8, %ymm7
vpshufb mask_517_1(%rip), %ymm7, %ymm6
vpand mask_518_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpshufb mask_519_1(%rip), %ymm7, %ymm6
vpand mask_520_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpshufb mask_521_1(%rip), %ymm7, %ymm6
vpand mask_522_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpermq $78, %ymm7, %ymm9
vpshufb mask_523_1(%rip), %ymm9, %ymm6
vpand mask_524_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_525_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_526_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_527_1(%rip), %ymm9, %ymm6
vpand mask_528_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_529_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_530_1(%rip), %ymm9, %ymm6
vpand mask_531_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpsllq $2, %ymm8, %ymm7
vpshufb mask_532_1(%rip), %ymm7, %ymm6
vpand mask_533_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_534_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_535_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_536_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_537_1(%rip), %ymm7, %ymm6
vpand mask_538_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_539_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_540_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_541_1(%rip), %ymm7, %ymm6
vpand mask_542_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_543_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_544_1(%rip), %ymm7, %ymm6
vpand mask_545_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpermq $78, %ymm7, %ymm9
vpshufb mask_546_1(%rip), %ymm9, %ymm6
vpand mask_547_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_548_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_549_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_550_1(%rip), %ymm9, %ymm6
vpand mask_551_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_552_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_553_1(%rip), %ymm9, %ymm6
vpand mask_554_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_555_1(%rip), %ymm9, %ymm6
vpand mask_556_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_557_1(%rip), %ymm9, %ymm6
vpand mask_558_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpsrlq $61, %ymm8, %ymm6
vpsllq $3, %ymm8, %ymm5
vpermq $147, %ymm6, %ymm7
vpxor %ymm5, %ymm7, %ymm7
vpshufb mask_559_1(%rip), %ymm7, %ymm6
vpand mask_560_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpshufb mask_561_1(%rip), %ymm7, %ymm6
vpand mask_562_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpshufb mask_563_1(%rip), %ymm7, %ymm6
vpand mask_564_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_565_1(%rip), %ymm7, %ymm6
vpand mask_566_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm9
vpshufb mask_567_1(%rip), %ymm9, %ymm6
vpand mask_568_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_569_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_570_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_571_1(%rip), %ymm9, %ymm6
vpand mask_572_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_573_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_574_1(%rip), %ymm9, %ymm6
vpand mask_575_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vmovdqa 96(%rsi), %ymm0
vpshufb mask_576_1(%rip), %ymm0, %ymm6
vpand mask_577_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_578_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_579_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_580_1(%rip), %ymm0, %ymm6
vpand mask_581_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_582_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpermq $78, %ymm0, %ymm9
vpsllq $1, %ymm0, %ymm7
vpermq $78, %ymm7, %ymm9
vpshufb mask_583_1(%rip), %ymm9, %ymm6
vpand mask_584_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_585_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_586_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_587_1(%rip), %ymm9, %ymm6
vpand mask_588_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_589_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpsllq $2, %ymm0, %ymm7
vpshufb mask_590_1(%rip), %ymm7, %ymm6
vpand mask_591_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_592_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_593_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_594_1(%rip), %ymm7, %ymm6
vpand mask_595_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_596_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm9
vpsllq $3, %ymm0, %ymm7
vpshufb mask_597_1(%rip), %ymm7, %ymm6
vpand mask_598_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_599_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_600_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_601_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_602_1(%rip), %ymm7, %ymm6
vpand mask_603_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_604_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_605_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpshufb mask_606_1(%rip), %ymm7, %ymm6
vpand mask_607_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpand mask_608_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm4, %ymm4
vpermq $78, %ymm7, %ymm9
vpsllq $4, %ymm0, %ymm7
vpermq $78, %ymm7, %ymm9
vpshufb mask_609_1(%rip), %ymm9, %ymm6
vpand mask_610_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_611_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_612_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_613_1(%rip), %ymm9, %ymm6
vpand mask_614_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_615_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpsllq $5, %ymm0, %ymm7
vpshufb mask_616_1(%rip), %ymm7, %ymm6
vpand mask_617_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_618_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_619_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_620_1(%rip), %ymm7, %ymm6
vpand mask_621_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_622_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpermq $78, %ymm7, %ymm9
vpsllq $6, %ymm0, %ymm7
vpermq $78, %ymm7, %ymm9
vpshufb mask_623_1(%rip), %ymm9, %ymm6
vpand mask_624_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_625_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_626_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_627_1(%rip), %ymm9, %ymm6
vpand mask_628_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_629_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpsllq $7, %ymm0, %ymm7
vpermq $78, %ymm7, %ymm9
vpshufb mask_630_1(%rip), %ymm9, %ymm6
vpand mask_631_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm1, %ymm1
vpand mask_632_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_633_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vpshufb mask_634_1(%rip), %ymm9, %ymm6
vpand mask_635_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm2, %ymm2
vpand mask_636_1(%rip), %ymm6, %ymm5
vpxor %ymm5, %ymm3, %ymm3
vmovdqa %ymm1, 0(%rdi)
vmovdqa %ymm2, 32(%rdi)
vmovdqa %ymm3, 64(%rdi)
vmovdqa %ymm4, 96(%rdi)
ret
